"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import bilireq.grpc.protos.bilibili.app.card.v1.card_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Bubble(google.protobuf.message.Message):
    """气泡信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUBBLE_CONTENT_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    STIME_FIELD_NUMBER: builtins.int
    bubble_content: builtins.str
    """文案"""
    version: builtins.int
    """版本"""
    stime: builtins.int
    """起始时间"""
    def __init__(
        self,
        *,
        bubble_content: builtins.str = ...,
        version: builtins.int = ...,
        stime: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bubble_content", b"bubble_content", "stime", b"stime", "version", b"version"]) -> None: ...

global___Bubble = Bubble

@typing_extensions.final
class Config(google.protobuf.message.Message):
    """配置信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_TITLE_FIELD_NUMBER: builtins.int
    BOTTOM_TEXT_FIELD_NUMBER: builtins.int
    BOTTOM_TEXT_COVER_FIELD_NUMBER: builtins.int
    BOTTOM_TEXT_URL_FIELD_NUMBER: builtins.int
    TOP_ITEMS_FIELD_NUMBER: builtins.int
    HEAD_IMAGE_FIELD_NUMBER: builtins.int
    PAGE_ITEMS_FIELD_NUMBER: builtins.int
    HIT_FIELD_NUMBER: builtins.int
    item_title: builtins.str
    """标题"""
    bottom_text: builtins.str
    """底部文案"""
    bottom_text_cover: builtins.str
    """底部图片url"""
    bottom_text_url: builtins.str
    """底部跳转页url"""
    @property
    def top_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EntranceShow]:
        """顶部按钮信息列表"""
    head_image: builtins.str
    """头图url"""
    @property
    def page_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EntranceShow]:
        """当前页按钮信息"""
    hit: builtins.int
    """"""
    def __init__(
        self,
        *,
        item_title: builtins.str = ...,
        bottom_text: builtins.str = ...,
        bottom_text_cover: builtins.str = ...,
        bottom_text_url: builtins.str = ...,
        top_items: collections.abc.Iterable[global___EntranceShow] | None = ...,
        head_image: builtins.str = ...,
        page_items: collections.abc.Iterable[global___EntranceShow] | None = ...,
        hit: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bottom_text", b"bottom_text", "bottom_text_cover", b"bottom_text_cover", "bottom_text_url", b"bottom_text_url", "head_image", b"head_image", "hit", b"hit", "item_title", b"item_title", "page_items", b"page_items", "top_items", b"top_items"]) -> None: ...

global___Config = Config

@typing_extensions.final
class EntranceShow(google.protobuf.message.Message):
    """按钮信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    MODULE_ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    BUBBLE_FIELD_NUMBER: builtins.int
    ENTRANCE_ID_FIELD_NUMBER: builtins.int
    TOP_PHOTO_FIELD_NUMBER: builtins.int
    ENTRANCE_TYPE_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """按钮图标url"""
    title: builtins.str
    """按钮名"""
    module_id: builtins.str
    """入口模块id"""
    uri: builtins.str
    """跳转uri"""
    @property
    def bubble(self) -> global___Bubble:
        """气泡信息"""
    entrance_id: builtins.int
    """入口id"""
    top_photo: builtins.str
    """头图url"""
    entrance_type: builtins.int
    """入口类型"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        module_id: builtins.str = ...,
        uri: builtins.str = ...,
        bubble: global___Bubble | None = ...,
        entrance_id: builtins.int = ...,
        top_photo: builtins.str = ...,
        entrance_type: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bubble", b"bubble"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bubble", b"bubble", "entrance_id", b"entrance_id", "entrance_type", b"entrance_type", "icon", b"icon", "module_id", b"module_id", "title", b"title", "top_photo", b"top_photo", "uri", b"uri"]) -> None: ...

global___EntranceShow = EntranceShow

@typing_extensions.final
class PopularReply(google.protobuf.message.Message):
    """热门列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    VER_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.app.card.v1.card_pb2.Card]:
        """卡片列表"""
    @property
    def config(self) -> global___Config:
        """配置信息"""
    ver: builtins.str
    """版本"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[bilibili.app.card.v1.card_pb2.Card] | None = ...,
        config: global___Config | None = ...,
        ver: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "items", b"items", "ver", b"ver"]) -> None: ...

global___PopularReply = PopularReply

@typing_extensions.final
class PopularResultReq(google.protobuf.message.Message):
    """热门列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDX_FIELD_NUMBER: builtins.int
    LOGIN_EVENT_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    LAST_PARAM_FIELD_NUMBER: builtins.int
    VER_FIELD_NUMBER: builtins.int
    ENTRANCE_ID_FIELD_NUMBER: builtins.int
    LOCATION_IDS_FIELD_NUMBER: builtins.int
    SOURCE_ID_FIELD_NUMBER: builtins.int
    FLUSH_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    idx: builtins.int
    """排位索引id，为上此请求末尾项的idx"""
    login_event: builtins.int
    """登录标识
    1:未登陆用户第一页 2:登陆用户第一页
    """
    qn: builtins.int
    """清晰度(旧版)"""
    fnver: builtins.int
    """视频流版本(旧版)"""
    fnval: builtins.int
    """视频流功能(旧版)"""
    force_host: builtins.int
    """是否强制使用域名(旧版)"""
    fourk: builtins.int
    """是否4K(旧版)"""
    spmid: builtins.str
    """当前页面spm"""
    last_param: builtins.str
    """上此请求末尾项的param"""
    ver: builtins.str
    """上此请求的ver"""
    entrance_id: builtins.int
    """分品类热门的入口ID"""
    location_ids: builtins.str
    """热门定位id集合"""
    source_id: builtins.int
    """0:tag页 1:中间页"""
    flush: builtins.int
    """数据埋点上报
    0:代表手动刷新 1:代表自动刷新
    """
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
    def __init__(
        self,
        *,
        idx: builtins.int = ...,
        login_event: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.int = ...,
        spmid: builtins.str = ...,
        last_param: builtins.str = ...,
        ver: builtins.str = ...,
        entrance_id: builtins.int = ...,
        location_ids: builtins.str = ...,
        source_id: builtins.int = ...,
        flush: builtins.int = ...,
        player_args: bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entrance_id", b"entrance_id", "flush", b"flush", "fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "fourk", b"fourk", "idx", b"idx", "last_param", b"last_param", "location_ids", b"location_ids", "login_event", b"login_event", "player_args", b"player_args", "qn", b"qn", "source_id", b"source_id", "spmid", b"spmid", "ver", b"ver"]) -> None: ...

global___PopularResultReq = PopularResultReq



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/im/interfaces/v1/im.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.im.type import im_pb2 as bilibili_dot_im_dot_type_dot_im__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"bilibili/im/interfaces/v1/im.proto\x12\x18\x62ilibili.im.interface.v1\x1a\x19\x62ilibili/im/type/im.proto\"\x17\n\x08\x44ummyReq\x12\x0b\n\x03idl\x18\x01 \x01(\r\"\x10\n\x08\x44ummyRspJ\x04\x08\x01\x10\x02\"G\n\x0b\x45motionInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x05\x12\x0f\n\x07gif_url\x18\x04 \x01(\t\"+\n\tMsgDetail\x12\x0f\n\x07msg_key\x18\x01 \x01(\x03\x12\r\n\x05seqno\x18\x02 \x01(\x03\"\x89\x01\n\x10MsgFeedUnreadRsp\x12\x46\n\x06unread\x18\x01 \x03(\x0b\x32\x36.bilibili.im.interface.v1.MsgFeedUnreadRsp.UnreadEntry\x1a-\n\x0bUnreadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"#\n\x0eReqAckAssisMsg\x12\x11\n\tack_seqno\x18\x01 \x01(\x04\"@\n\x0eReqAckSessions\x12\x10\n\x08\x62\x65gin_ts\x18\x01 \x01(\x04\x12\x0e\n\x06\x65nd_ts\x18\x02 \x01(\r\x12\x0c\n\x04size\x18\x03 \x01(\r\"\x0e\n\x0cReqBatRmSess\"\x17\n\x15ReqCloseClearUnreadUI\"m\n\tReqGetMsg\x12\x11\n\ttalker_id\x18\x01 \x01(\x03\x12\x14\n\x0csession_type\x18\x02 \x01(\x05\x12\x37\n\nmsg_detail\x18\x03 \x03(\x0b\x32#.bilibili.im.interface.v1.MsgDetail\"\xc1\x01\n\x0eReqGetSessions\x12\x10\n\x08\x62\x65gin_ts\x18\x01 \x01(\x04\x12\x0e\n\x06\x65nd_ts\x18\x02 \x01(\x04\x12\x0c\n\x04size\x18\x03 \x01(\r\x12\x14\n\x0csession_type\x18\x04 \x01(\r\x12\x15\n\runfollow_fold\x18\x05 \x01(\r\x12\x12\n\ngroup_fold\x18\x06 \x01(\r\x12\x11\n\tsort_rule\x18\x07 \x01(\r\x12\x15\n\rteenager_mode\x18\x08 \x01(\r\x12\x14\n\x0clessons_mode\x18\t \x01(\r\"Z\n\x16ReqGetSpecificSessions\x12@\n\x0ftalker_sessions\x18\x01 \x03(\x0b\x32\'.bilibili.im.interface.v1.SimpleSession\"6\n\x10ReqGroupAssisMsg\x12\x14\n\x0c\x63lient_seqno\x18\x01 \x01(\x04\x12\x0c\n\x04size\x18\x02 \x01(\r\"-\n\x0bReqLiveInfo\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x11\n\ttalker_id\x18\x02 \x01(\x03\"]\n\x0eReqNewSessions\x12\x10\n\x08\x62\x65gin_ts\x18\x01 \x01(\x04\x12\x0c\n\x04size\x18\x02 \x01(\r\x12\x15\n\rteenager_mode\x18\x03 \x01(\r\x12\x14\n\x0clessons_mode\x18\x04 \x01(\r\"6\n\x0fReqRelationSync\x12#\n\x1b\x63lient_relation_oplog_seqno\x18\x01 \x01(\x04\";\n\x10ReqRemoveSession\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\"u\n\nReqSendMsg\x12\"\n\x03msg\x18\x01 \x01(\x0b\x32\x15.bilibili.im.type.Msg\x12\x0e\n\x06\x63ookie\x18\x02 \x01(\t\x12\x0f\n\x07\x63ookie2\x18\x03 \x01(\t\x12\x12\n\nerror_code\x18\x04 \x01(\x05\x12\x0e\n\x06\x64\x65v_id\x18\x05 \x01(\t\"H\n\x10ReqSessionDetail\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x0b\n\x03uid\x18\x03 \x01(\x04\"Q\n\x11ReqSessionDetails\x12<\n\x08sess_ids\x18\x01 \x03(\x0b\x32*.bilibili.im.interface.v1.ReqSessionDetail\"\x8d\x01\n\rReqSessionMsg\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\x05\x12\x11\n\tend_seqno\x18\x03 \x01(\x04\x12\x13\n\x0b\x62\x65gin_seqno\x18\x04 \x01(\x04\x12\x0c\n\x04size\x18\x05 \x01(\x05\x12\r\n\x05order\x18\x06 \x01(\x05\x12\x0e\n\x06\x64\x65v_id\x18\x07 \x01(\t\"E\n\tReqSetTop\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x0f\n\x07op_type\x18\x03 \x01(\r\"\x1c\n\x0cReqShareList\x12\x0c\n\x04size\x18\x01 \x01(\x05\"]\n\x14ReqShowClearUnreadUI\x12\x13\n\x0bunread_type\x18\x01 \x01(\x05\x12\x1a\n\x12show_unfollow_list\x18\x02 \x01(\x05\x12\x14\n\x0cshow_dustbin\x18\x04 \x01(\x05\"e\n\x0fReqSingleUnread\x12\x13\n\x0bunread_type\x18\x01 \x01(\x05\x12\x1a\n\x12show_unfollow_list\x18\x02 \x01(\x05\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x14\n\x0cshow_dustbin\x18\x04 \x01(\x05\"[\n\x17ReqSpecificSingleUnread\x12@\n\x0ftalker_sessions\x18\x01 \x03(\x0b\x32\'.bilibili.im.interface.v1.SimpleSession\"\"\n\nReqSyncAck\x12\x14\n\x0c\x63lient_seqno\x18\x01 \x01(\x04\"\xa3\x01\n\x0eReqTotalUnread\x12\x13\n\x0bunread_type\x18\x01 \x01(\x05\x12\x1a\n\x12show_unfollow_list\x18\x02 \x01(\x05\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x14\n\x0cshow_dustbin\x18\x04 \x01(\x05\x12\x17\n\x0fsingleunread_on\x18\x05 \x01(\x05\x12\x12\n\nmsgfeed_on\x18\x06 \x01(\x05\x12\x10\n\x08sysup_on\x18\x07 \x01(\x05\"J\n\x0cReqUpdateAck\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x11\n\tack_seqno\x18\x03 \x01(\x04\"D\n\x12ReqUpdateIntercept\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x11\n\ttalker_id\x18\x02 \x01(\x03\x12\x0e\n\x06status\x18\x03 \x01(\x05\"\x16\n\x14ReqUpdateTotalUnread\"\x17\n\x15RspCloseClearUnreadUI\"/\n\tRspGetMsg\x12\"\n\x03msg\x18\x01 \x03(\x0b\x32\x15.bilibili.im.type.Msg\"4\n\x0bRspLiveInfo\x12\x13\n\x0blive_status\x18\x01 \x01(\x03\x12\x10\n\x08jump_url\x18\x02 \x01(\t\"(\n\x10RspMyGroupUnread\x12\x14\n\x0cunread_count\x18\x01 \x01(\r\"\xe6\x01\n\x0fRspRelationSync\x12\x0c\n\x04\x66ull\x18\x01 \x01(\x05\x12\x34\n\rrelation_logs\x18\x02 \x03(\x0b\x32\x1d.bilibili.im.type.RelationLog\x12\x35\n\x0b\x66riend_list\x18\x03 \x03(\x0b\x32 .bilibili.im.type.FriendRelation\x12#\n\x1bserver_relation_oplog_seqno\x18\x04 \x01(\x04\x12\x33\n\ngroup_list\x18\x05 \x03(\x0b\x32\x1f.bilibili.im.type.GroupRelation\"\xa0\x01\n\nRspSendMsg\x12\x0f\n\x07msg_key\x18\x01 \x01(\x04\x12\x36\n\x07\x65_infos\x18\x02 \x03(\x0b\x32%.bilibili.im.interface.v1.EmotionInfo\x12\x13\n\x0bmsg_content\x18\x03 \x01(\t\x12\x34\n\rkey_hit_infos\x18\x04 \x01(\x0b\x32\x1d.bilibili.im.type.KeyHitInfos\"F\n\x11RspSessionDetails\x12\x31\n\nsess_infos\x18\x01 \x03(\x0b\x32\x1d.bilibili.im.type.SessionInfo\"\xa8\x01\n\rRspSessionMsg\x12\'\n\x08messages\x18\x01 \x03(\x0b\x32\x15.bilibili.im.type.Msg\x12\x10\n\x08has_more\x18\x02 \x01(\x05\x12\x11\n\tmin_seqno\x18\x03 \x01(\x04\x12\x11\n\tmax_seqno\x18\x04 \x01(\x04\x12\x36\n\x07\x65_infos\x18\x05 \x03(\x0b\x32%.bilibili.im.interface.v1.EmotionInfo\"\xa2\x02\n\x0bRspSessions\x12\x33\n\x0csession_list\x18\x01 \x03(\x0b\x32\x1d.bilibili.im.type.SessionInfo\x12\x10\n\x08has_more\x18\x02 \x01(\r\x12\x1d\n\x15\x61nti_disturb_cleaning\x18\x03 \x01(\x08\x12\x1d\n\x15is_address_list_empty\x18\x04 \x01(\x05\x12H\n\nsystem_msg\x18\x05 \x03(\x0b\x32\x34.bilibili.im.interface.v1.RspSessions.SystemMsgEntry\x12\x12\n\nshow_level\x18\x06 \x01(\x08\x1a\x30\n\x0eSystemMsgEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"l\n\x0cRspShareList\x12@\n\x0csession_list\x18\x01 \x03(\x0b\x32*.bilibili.im.interface.v1.ShareSessionInfo\x12\x1a\n\x12IsAddressListEmpty\x18\x02 \x01(\x05\"5\n\x14RspShowClearUnreadUI\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x0c\n\x04text\x18\x02 \x01(\t\"\xce\x01\n\x0fRspSingleUnread\x12\x17\n\x0funfollow_unread\x18\x01 \x01(\x04\x12\x15\n\rfollow_unread\x18\x02 \x01(\x04\x12\x19\n\x11unfollow_push_msg\x18\x03 \x01(\r\x12\x18\n\x10\x64ustbin_push_msg\x18\x04 \x01(\x05\x12\x16\n\x0e\x64ustbin_unread\x18\x05 \x01(\x03\x12\x1f\n\x17\x62iz_msg_unfollow_unread\x18\x06 \x01(\x03\x12\x1d\n\x15\x62iz_msg_follow_unread\x18\x07 \x01(\x03\"\xc8\x01\n\x17RspSpecificSingleUnread\x12_\n\x0ftalkerUnreadCnt\x18\x01 \x03(\x0b\x32\x46.bilibili.im.interface.v1.RspSpecificSingleUnread.TalkerUnreadCntEntry\x12\x14\n\x0c\x61llUnreadCnt\x18\x02 \x01(\x04\x1a\x36\n\x14TalkerUnreadCntEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\"\x0c\n\nRspSyncAck\"\x95\x02\n\x0eRspTotalUnread\x12O\n\x15session_single_unread\x18\x01 \x01(\x0b\x32\x30.bilibili.im.interface.v1.SessionSingleUnreadRsp\x12\x43\n\x0fmsg_feed_unread\x18\x02 \x01(\x0b\x32*.bilibili.im.interface.v1.MsgFeedUnreadRsp\x12W\n\x1asys_msg_interface_last_msg\x18\x03 \x01(\x0b\x32\x33.bilibili.im.interface.v1.SysMsgInterfaceLastMsgRsp\x12\x14\n\x0ctotal_unread\x18\x04 \x01(\x05\"\x16\n\x14RspUpdateTotalUnread\"\x95\x01\n\x16SessionSingleUnreadRsp\x12\x17\n\x0funfollow_unread\x18\x01 \x01(\x03\x12\x15\n\rfollow_unread\x18\x02 \x01(\x03\x12\x19\n\x11unfollow_push_msg\x18\x03 \x01(\x05\x12\x18\n\x10\x64ustbin_push_msg\x18\x04 \x01(\x05\x12\x16\n\x0e\x64ustbin_unread\x18\x05 \x01(\x03\"g\n\x10ShareSessionInfo\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0ctalker_uname\x18\x02 \x01(\t\x12\x13\n\x0btalker_icon\x18\x03 \x01(\t\x12\x15\n\rofficial_type\x18\x04 \x01(\x05\"8\n\rSimpleSession\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\"T\n\x19SysMsgInterfaceLastMsgRsp\x12\x0e\n\x06unread\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\x03*8\n\tENUM_FOLD\x12\x0b\n\x07\x46OLD_NO\x10\x00\x12\x0c\n\x08\x46OLD_YES\x10\x01\x12\x10\n\x0c\x46OLD_UNKNOWN\x10\x02*r\n\x10\x45NUM_UNREAD_TYPE\x12\x13\n\x0fUNREAD_TYPE_ALL\x10\x00\x12\x16\n\x12UNREAD_TYPE_FOLLOW\x10\x01\x12\x18\n\x14UNREAD_TYPE_UNFOLLOW\x10\x02\x12\x17\n\x13UNREAD_TYPE_DUSTBIN\x10\x03*\x8a\x01\n\x0cSESSION_TYPE\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fUN_FOLD_SESSION\x10\x01\x12\x1c\n\x18UN_FOLLOW_SINGLE_SESSION\x10\x02\x12\x14\n\x10MY_GROUP_SESSION\x10\x03\x12\x0f\n\x0b\x41LL_SESSION\x10\x04\x12\x13\n\x0f\x44USTBIN_SESSION\x10\x05\x32\xb5\x14\n\x0bImInterface\x12U\n\x07SendMsg\x12$.bilibili.im.interface.v1.ReqSendMsg\x1a$.bilibili.im.interface.v1.RspSendMsg\x12\x64\n\x0cSyncRelation\x12).bilibili.im.interface.v1.ReqRelationSync\x1a).bilibili.im.interface.v1.RspRelationSync\x12U\n\x07SyncAck\x12$.bilibili.im.interface.v1.ReqSyncAck\x1a$.bilibili.im.interface.v1.RspSyncAck\x12h\n\x14SyncFetchSessionMsgs\x12\'.bilibili.im.interface.v1.ReqSessionMsg\x1a\'.bilibili.im.interface.v1.RspSessionMsg\x12^\n\x0bGetSessions\x12(.bilibili.im.interface.v1.ReqGetSessions\x1a%.bilibili.im.interface.v1.RspSessions\x12^\n\x0bNewSessions\x12(.bilibili.im.interface.v1.ReqNewSessions\x1a%.bilibili.im.interface.v1.RspSessions\x12^\n\x0b\x41\x63kSessions\x12(.bilibili.im.interface.v1.ReqAckSessions\x1a%.bilibili.im.interface.v1.RspSessions\x12W\n\tUpdateAck\x12&.bilibili.im.interface.v1.ReqUpdateAck\x1a\".bilibili.im.interface.v1.DummyRsp\x12Q\n\x06SetTop\x12#.bilibili.im.interface.v1.ReqSetTop\x1a\".bilibili.im.interface.v1.DummyRsp\x12_\n\rRemoveSession\x12*.bilibili.im.interface.v1.ReqRemoveSession\x1a\".bilibili.im.interface.v1.DummyRsp\x12\x64\n\x0cSingleUnread\x12).bilibili.im.interface.v1.ReqSingleUnread\x1a).bilibili.im.interface.v1.RspSingleUnread\x12_\n\rMyGroupUnread\x12\".bilibili.im.interface.v1.DummyReq\x1a*.bilibili.im.interface.v1.RspMyGroupUnread\x12Y\n\x0fUpdateUnflwRead\x12\".bilibili.im.interface.v1.DummyReq\x1a\".bilibili.im.interface.v1.DummyRsp\x12\x64\n\rGroupAssisMsg\x12*.bilibili.im.interface.v1.ReqGroupAssisMsg\x1a\'.bilibili.im.interface.v1.RspSessionMsg\x12[\n\x0b\x41\x63kAssisMsg\x12(.bilibili.im.interface.v1.ReqAckAssisMsg\x1a\".bilibili.im.interface.v1.DummyRsp\x12Z\n\rSessionDetail\x12*.bilibili.im.interface.v1.ReqSessionDetail\x1a\x1d.bilibili.im.type.SessionInfo\x12k\n\x0f\x42\x61tchSessDetail\x12+.bilibili.im.interface.v1.ReqSessionDetails\x1a+.bilibili.im.interface.v1.RspSessionDetails\x12]\n\x0f\x42\x61tchRmSessions\x12&.bilibili.im.interface.v1.ReqBatRmSess\x1a\".bilibili.im.interface.v1.DummyRsp\x12[\n\tShareList\x12&.bilibili.im.interface.v1.ReqShareList\x1a&.bilibili.im.interface.v1.RspShareList\x12|\n\x14SpecificSingleUnread\x12\x31.bilibili.im.interface.v1.ReqSpecificSingleUnread\x1a\x31.bilibili.im.interface.v1.RspSpecificSingleUnread\x12n\n\x13GetSpecificSessions\x12\x30.bilibili.im.interface.v1.ReqGetSpecificSessions\x1a%.bilibili.im.interface.v1.RspSessions\x12[\n\x0bGetLiveInfo\x12%.bilibili.im.interface.v1.ReqLiveInfo\x1a%.bilibili.im.interface.v1.RspLiveInfo\x12\x64\n\x0eGetTotalUnread\x12(.bilibili.im.interface.v1.ReqTotalUnread\x1a(.bilibili.im.interface.v1.RspTotalUnread\x12s\n\x11ShowClearUnreadUI\x12..bilibili.im.interface.v1.ReqShowClearUnreadUI\x1a..bilibili.im.interface.v1.RspShowClearUnreadUI\x12v\n\x12\x43loseClearUnreadUI\x12/.bilibili.im.interface.v1.ReqCloseClearUnreadUI\x1a/.bilibili.im.interface.v1.RspCloseClearUnreadUI\x12s\n\x11UpdateTotalUnread\x12..bilibili.im.interface.v1.ReqUpdateTotalUnread\x1a..bilibili.im.interface.v1.RspUpdateTotalUnreadb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.im.interfaces.v1.im_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MSGFEEDUNREADRSP_UNREADENTRY._options = None
  _MSGFEEDUNREADRSP_UNREADENTRY._serialized_options = b'8\001'
  _RSPSESSIONS_SYSTEMMSGENTRY._options = None
  _RSPSESSIONS_SYSTEMMSGENTRY._serialized_options = b'8\001'
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._options = None
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._serialized_options = b'8\001'
  _ENUM_FOLD._serialized_start=4832
  _ENUM_FOLD._serialized_end=4888
  _ENUM_UNREAD_TYPE._serialized_start=4890
  _ENUM_UNREAD_TYPE._serialized_end=5004
  _SESSION_TYPE._serialized_start=5007
  _SESSION_TYPE._serialized_end=5145
  _DUMMYREQ._serialized_start=91
  _DUMMYREQ._serialized_end=114
  _DUMMYRSP._serialized_start=116
  _DUMMYRSP._serialized_end=132
  _EMOTIONINFO._serialized_start=134
  _EMOTIONINFO._serialized_end=205
  _MSGDETAIL._serialized_start=207
  _MSGDETAIL._serialized_end=250
  _MSGFEEDUNREADRSP._serialized_start=253
  _MSGFEEDUNREADRSP._serialized_end=390
  _MSGFEEDUNREADRSP_UNREADENTRY._serialized_start=345
  _MSGFEEDUNREADRSP_UNREADENTRY._serialized_end=390
  _REQACKASSISMSG._serialized_start=392
  _REQACKASSISMSG._serialized_end=427
  _REQACKSESSIONS._serialized_start=429
  _REQACKSESSIONS._serialized_end=493
  _REQBATRMSESS._serialized_start=495
  _REQBATRMSESS._serialized_end=509
  _REQCLOSECLEARUNREADUI._serialized_start=511
  _REQCLOSECLEARUNREADUI._serialized_end=534
  _REQGETMSG._serialized_start=536
  _REQGETMSG._serialized_end=645
  _REQGETSESSIONS._serialized_start=648
  _REQGETSESSIONS._serialized_end=841
  _REQGETSPECIFICSESSIONS._serialized_start=843
  _REQGETSPECIFICSESSIONS._serialized_end=933
  _REQGROUPASSISMSG._serialized_start=935
  _REQGROUPASSISMSG._serialized_end=989
  _REQLIVEINFO._serialized_start=991
  _REQLIVEINFO._serialized_end=1036
  _REQNEWSESSIONS._serialized_start=1038
  _REQNEWSESSIONS._serialized_end=1131
  _REQRELATIONSYNC._serialized_start=1133
  _REQRELATIONSYNC._serialized_end=1187
  _REQREMOVESESSION._serialized_start=1189
  _REQREMOVESESSION._serialized_end=1248
  _REQSENDMSG._serialized_start=1250
  _REQSENDMSG._serialized_end=1367
  _REQSESSIONDETAIL._serialized_start=1369
  _REQSESSIONDETAIL._serialized_end=1441
  _REQSESSIONDETAILS._serialized_start=1443
  _REQSESSIONDETAILS._serialized_end=1524
  _REQSESSIONMSG._serialized_start=1527
  _REQSESSIONMSG._serialized_end=1668
  _REQSETTOP._serialized_start=1670
  _REQSETTOP._serialized_end=1739
  _REQSHARELIST._serialized_start=1741
  _REQSHARELIST._serialized_end=1769
  _REQSHOWCLEARUNREADUI._serialized_start=1771
  _REQSHOWCLEARUNREADUI._serialized_end=1864
  _REQSINGLEUNREAD._serialized_start=1866
  _REQSINGLEUNREAD._serialized_end=1967
  _REQSPECIFICSINGLEUNREAD._serialized_start=1969
  _REQSPECIFICSINGLEUNREAD._serialized_end=2060
  _REQSYNCACK._serialized_start=2062
  _REQSYNCACK._serialized_end=2096
  _REQTOTALUNREAD._serialized_start=2099
  _REQTOTALUNREAD._serialized_end=2262
  _REQUPDATEACK._serialized_start=2264
  _REQUPDATEACK._serialized_end=2338
  _REQUPDATEINTERCEPT._serialized_start=2340
  _REQUPDATEINTERCEPT._serialized_end=2408
  _REQUPDATETOTALUNREAD._serialized_start=2410
  _REQUPDATETOTALUNREAD._serialized_end=2432
  _RSPCLOSECLEARUNREADUI._serialized_start=2434
  _RSPCLOSECLEARUNREADUI._serialized_end=2457
  _RSPGETMSG._serialized_start=2459
  _RSPGETMSG._serialized_end=2506
  _RSPLIVEINFO._serialized_start=2508
  _RSPLIVEINFO._serialized_end=2560
  _RSPMYGROUPUNREAD._serialized_start=2562
  _RSPMYGROUPUNREAD._serialized_end=2602
  _RSPRELATIONSYNC._serialized_start=2605
  _RSPRELATIONSYNC._serialized_end=2835
  _RSPSENDMSG._serialized_start=2838
  _RSPSENDMSG._serialized_end=2998
  _RSPSESSIONDETAILS._serialized_start=3000
  _RSPSESSIONDETAILS._serialized_end=3070
  _RSPSESSIONMSG._serialized_start=3073
  _RSPSESSIONMSG._serialized_end=3241
  _RSPSESSIONS._serialized_start=3244
  _RSPSESSIONS._serialized_end=3534
  _RSPSESSIONS_SYSTEMMSGENTRY._serialized_start=3486
  _RSPSESSIONS_SYSTEMMSGENTRY._serialized_end=3534
  _RSPSHARELIST._serialized_start=3536
  _RSPSHARELIST._serialized_end=3644
  _RSPSHOWCLEARUNREADUI._serialized_start=3646
  _RSPSHOWCLEARUNREADUI._serialized_end=3699
  _RSPSINGLEUNREAD._serialized_start=3702
  _RSPSINGLEUNREAD._serialized_end=3908
  _RSPSPECIFICSINGLEUNREAD._serialized_start=3911
  _RSPSPECIFICSINGLEUNREAD._serialized_end=4111
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._serialized_start=4057
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._serialized_end=4111
  _RSPSYNCACK._serialized_start=4113
  _RSPSYNCACK._serialized_end=4125
  _RSPTOTALUNREAD._serialized_start=4128
  _RSPTOTALUNREAD._serialized_end=4405
  _RSPUPDATETOTALUNREAD._serialized_start=4407
  _RSPUPDATETOTALUNREAD._serialized_end=4429
  _SESSIONSINGLEUNREADRSP._serialized_start=4432
  _SESSIONSINGLEUNREADRSP._serialized_end=4581
  _SHARESESSIONINFO._serialized_start=4583
  _SHARESESSIONINFO._serialized_end=4686
  _SIMPLESESSION._serialized_start=4688
  _SIMPLESESSION._serialized_end=4744
  _SYSMSGINTERFACELASTMSGRSP._serialized_start=4746
  _SYSMSGINTERFACELASTMSGRSP._serialized_end=4830
  _IMINTERFACE._serialized_start=5148
  _IMINTERFACE._serialized_end=7761
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.polymer.app.search.v1 import search_pb2 as bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2


class SearchStub(object):
    """
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SearchAll = channel.unary_unary(
                '/bilibili.polymer.app.search.v1.Search/SearchAll',
                request_serializer=bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchAllRequest.SerializeToString,
                response_deserializer=bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchAllResponse.FromString,
                )
        self.SearchByType = channel.unary_unary(
                '/bilibili.polymer.app.search.v1.Search/SearchByType',
                request_serializer=bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchByTypeRequest.SerializeToString,
                response_deserializer=bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchByTypeResponse.FromString,
                )
        self.SearchComic = channel.unary_unary(
                '/bilibili.polymer.app.search.v1.Search/SearchComic',
                request_serializer=bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchComicRequest.SerializeToString,
                response_deserializer=bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchComicResponse.FromString,
                )


class SearchServicer(object):
    """
    """

    def SearchAll(self, request, context):
        """搜索所有类型结果
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchByType(self, request, context):
        """搜索指定类型结果
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchComic(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SearchServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SearchAll': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchAll,
                    request_deserializer=bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchAllRequest.FromString,
                    response_serializer=bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchAllResponse.SerializeToString,
            ),
            'SearchByType': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchByType,
                    request_deserializer=bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchByTypeRequest.FromString,
                    response_serializer=bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchByTypeResponse.SerializeToString,
            ),
            'SearchComic': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchComic,
                    request_deserializer=bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchComicRequest.FromString,
                    response_serializer=bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchComicResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.polymer.app.search.v1.Search', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Search(object):
    """
    """

    @staticmethod
    def SearchAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.polymer.app.search.v1.Search/SearchAll',
            bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchAllRequest.SerializeToString,
            bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchAllResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchByType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.polymer.app.search.v1.Search/SearchByType',
            bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchByTypeRequest.SerializeToString,
            bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchByTypeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchComic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.polymer.app.search.v1.Search/SearchComic',
            bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchComicRequest.SerializeToString,
            bilibili_dot_polymer_dot_app_dot_search_dot_v1_dot_search__pb2.SearchComicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Item(google.protobuf.message.Message):
    """排行榜列表项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    FAVOURITE_FIELD_NUMBER: builtins.int
    PUB_DATE_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    RNAME_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    PTS_FIELD_NUMBER: builtins.int
    COOPERATION_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    FOLLOWER_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    CHILDREN_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面url"""
    param: builtins.str
    """参数(稿件avid)"""
    uri: builtins.str
    """跳转uri"""
    redirect_url: builtins.str
    """重定向url"""
    goto: builtins.str
    """跳转类型
    av:视频稿件
    """
    play: builtins.int
    """播放数"""
    danmaku: builtins.int
    """弹幕数"""
    mid: builtins.int
    """UP主mid"""
    name: builtins.str
    """UP主昵称"""
    face: builtins.str
    """UP主头像url"""
    reply: builtins.int
    """评论数"""
    favourite: builtins.int
    """收藏数"""
    pub_date: builtins.int
    """发布时间"""
    rid: builtins.int
    """分区tid"""
    rname: builtins.str
    """子分区名"""
    duration: builtins.int
    """视频总时长"""
    like: builtins.int
    """点赞数"""
    cid: builtins.int
    """1P cid"""
    pts: builtins.int
    """综合评分"""
    cooperation: builtins.str
    """合作视频文案"""
    attribute: builtins.int
    """属性位
    0:未关注 1:已关注
    """
    follower: builtins.int
    """UP主粉丝数"""
    @property
    def official_verify(self) -> global___OfficialVerify:
        """UP主认证信息"""
    @property
    def children(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Item]:
        """同一UP收起子项列表"""
    @property
    def relation(self) -> global___Relation:
        """关系信息"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        param: builtins.str = ...,
        uri: builtins.str = ...,
        redirect_url: builtins.str = ...,
        goto: builtins.str = ...,
        play: builtins.int = ...,
        danmaku: builtins.int = ...,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
        reply: builtins.int = ...,
        favourite: builtins.int = ...,
        pub_date: builtins.int = ...,
        rid: builtins.int = ...,
        rname: builtins.str = ...,
        duration: builtins.int = ...,
        like: builtins.int = ...,
        cid: builtins.int = ...,
        pts: builtins.int = ...,
        cooperation: builtins.str = ...,
        attribute: builtins.int = ...,
        follower: builtins.int = ...,
        official_verify: global___OfficialVerify | None = ...,
        children: collections.abc.Iterable[global___Item] | None = ...,
        relation: global___Relation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["official_verify", b"official_verify", "relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute", b"attribute", "children", b"children", "cid", b"cid", "cooperation", b"cooperation", "cover", b"cover", "danmaku", b"danmaku", "duration", b"duration", "face", b"face", "favourite", b"favourite", "follower", b"follower", "goto", b"goto", "like", b"like", "mid", b"mid", "name", b"name", "official_verify", b"official_verify", "param", b"param", "play", b"play", "pts", b"pts", "pub_date", b"pub_date", "redirect_url", b"redirect_url", "relation", b"relation", "reply", b"reply", "rid", b"rid", "rname", b"rname", "title", b"title", "uri", b"uri"]) -> None: ...

global___Item = Item

@typing_extensions.final
class OfficialVerify(google.protobuf.message.Message):
    """认证信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    type: builtins.int
    """认证类型
    -1:无认证 0:个人认证 1:机构认证
    """
    desc: builtins.str
    """认证描述"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "type", b"type"]) -> None: ...

global___OfficialVerify = OfficialVerify

@typing_extensions.final
class RankAllResultReq(google.protobuf.message.Message):
    """全站排行榜-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORDER_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    order: builtins.str
    """必须为"all" """
    pn: builtins.int
    """页码
    默认1页
    """
    ps: builtins.int
    """每页项数
    默认100项，最大100
    """
    def __init__(
        self,
        *,
        order: builtins.str = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["order", b"order", "pn", b"pn", "ps", b"ps"]) -> None: ...

global___RankAllResultReq = RankAllResultReq

@typing_extensions.final
class RankListReply(google.protobuf.message.Message):
    """排行榜信息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Item]:
        """排行榜列表"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___Item] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items"]) -> None: ...

global___RankListReply = RankListReply

@typing_extensions.final
class RankRegionResultReq(google.protobuf.message.Message):
    """分区排行榜-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RID_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    rid: builtins.int
    """一级分区tid(二级分区不可用)
    0:全站
    """
    pn: builtins.int
    """页码
    默认1页
    """
    ps: builtins.int
    """每页项数
    默认100项，最大100
    """
    def __init__(
        self,
        *,
        rid: builtins.int = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pn", b"pn", "ps", b"ps", "rid", b"rid"]) -> None: ...

global___RankRegionResultReq = RankRegionResultReq

@typing_extensions.final
class Relation(google.protobuf.message.Message):
    """关系信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    IS_FOLLOWED_FIELD_NUMBER: builtins.int
    status: builtins.int
    """关系状态id
    1:未关注 2:已关注 3:被关注 4:互相关注
    """
    is_follow: builtins.int
    """是否关注"""
    is_followed: builtins.int
    """是否粉丝"""
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        is_follow: builtins.int = ...,
        is_followed: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow", b"is_follow", "is_followed", b"is_followed", "status", b"status"]) -> None: ...

global___Relation = Relation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _RoomStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RoomStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RoomStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Pause: _RoomStatus.ValueType  # 0
    """暂停:"""
    Play: _RoomStatus.ValueType  # 1
    """播放:"""
    End: _RoomStatus.ValueType  # 2
    """终止:"""

class RoomStatus(_RoomStatus, metaclass=_RoomStatusEnumTypeWrapper):
    """"""

Pause: RoomStatus.ValueType  # 0
"""暂停:"""
Play: RoomStatus.ValueType  # 1
"""播放:"""
End: RoomStatus.ValueType  # 2
"""终止:"""
global___RoomStatus = RoomStatus

@typing_extensions.final
class RoomEvent(google.protobuf.message.Message):
    """推送选项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOM_STATUS_FIELD_NUMBER: builtins.int
    ROOM_MESSAGE_FIELD_NUMBER: builtins.int
    room_status: global___RoomStatus.ValueType
    """RoomStatus 类型"""
    room_message: builtins.str
    """"""
    def __init__(
        self,
        *,
        room_status: global___RoomStatus.ValueType = ...,
        room_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["room_message", b"room_message", "room_status", b"room_status"]) -> None: ...

global___RoomEvent = RoomEvent



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Notify(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_ID_FIELD_NUMBER: builtins.int
    MSG_TYPE_FIELD_NUMBER: builtins.int
    RECEIVER_UID_FIELD_NUMBER: builtins.int
    RECEIVER_TYPE_FIELD_NUMBER: builtins.int
    STORY_VERSION_FIELD_NUMBER: builtins.int
    OP_HASH_FIELD_NUMBER: builtins.int
    OP_SENDER_FIELD_NUMBER: builtins.int
    OP_CONTENT_FIELD_NUMBER: builtins.int
    msg_id: builtins.int
    """消息唯一标示"""
    msg_type: builtins.int
    """消息类型"""
    receiver_uid: builtins.int
    """接收方uid"""
    receiver_type: builtins.int
    """接收方类型"""
    story_version: builtins.int
    """故事的版本"""
    op_hash: builtins.int
    """操作结果的hash值"""
    op_sender: builtins.int
    """操作产生用户的uid"""
    op_content: builtins.str
    """patch内容"""
    def __init__(
        self,
        *,
        msg_id: builtins.int = ...,
        msg_type: builtins.int = ...,
        receiver_uid: builtins.int = ...,
        receiver_type: builtins.int = ...,
        story_version: builtins.int = ...,
        op_hash: builtins.int = ...,
        op_sender: builtins.int = ...,
        op_content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg_id", b"msg_id", "msg_type", b"msg_type", "op_content", b"op_content", "op_hash", b"op_hash", "op_sender", b"op_sender", "receiver_type", b"receiver_type", "receiver_uid", b"receiver_uid", "story_version", b"story_version"]) -> None: ...

global___Notify = Notify



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/vega/deneb/v1/deneb.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"bilibili/vega/deneb/v1/deneb.proto\x12\x16\x62ilibili.vega.deneb.v1\x1a\x19google/protobuf/any.proto\"p\n\x11MessagePullsReply\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\x12\n\n\x02pn\x18\x02 \x01(\x05\x12\n\n\x02ps\x18\x03 \x01(\x05\x12\r\n\x05\x63ount\x18\x04 \x01(\x03\x12\x10\n\x08has_next\x18\x05 \x01(\x08\"S\n\x0fMessagePullsReq\x12\x14\n\x0cstart_seq_id\x18\x01 \x01(\x03\x12\x12\n\nend_seq_id\x18\x02 \x01(\x03\x12\n\n\x02pn\x18\x03 \x01(\x05\x12\n\n\x02ps\x18\x04 \x01(\x05\x32r\n\x0cVegaDenebRPC\x12\x62\n\x0cMessagePulls\x12\'.bilibili.vega.deneb.v1.MessagePullsReq\x1a).bilibili.vega.deneb.v1.MessagePullsReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.vega.deneb.v1.deneb_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGEPULLSREPLY._serialized_start=89
  _MESSAGEPULLSREPLY._serialized_end=201
  _MESSAGEPULLSREQ._serialized_start=203
  _MESSAGEPULLSREQ._serialized_end=286
  _VEGADENEBRPC._serialized_start=288
  _VEGADENEBRPC._serialized_end=402
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/pgc/gateway/player/v3/playurl.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.playershared import playershared_pb2 as bilibili_dot_playershared_dot_playershared__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,bilibili/pgc/gateway/player/v3/playurl.proto\x12\x1e\x62ilibili.pgc.gateway.player.v3\x1a(bilibili/playershared/playershared.proto\x1a\x19google/protobuf/any.proto\"\x81\x02\n\x0bPlayViewReq\x12,\n\x03vod\x18\x01 \x01(\x0b\x32\x1f.bilibili.playershared.VideoVod\x12\r\n\x05spmid\x18\x02 \x01(\t\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12\x16\n\x0eteenagers_mode\x18\x04 \x01(\x05\x12T\n\rextra_content\x18\x05 \x03(\x0b\x32=.bilibili.pgc.gateway.player.v3.PlayViewReq.ExtraContentEntry\x1a\x33\n\x11\x45xtraContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc0\x02\n\rPlayViewReply\x12\x30\n\x08vod_info\x18\x01 \x01(\x0b\x32\x1e.bilibili.playershared.VodInfo\x12\x39\n\rplay_arc_conf\x18\x02 \x01(\x0b\x32\".bilibili.playershared.PlayArcConf\x12(\n\nsupplement\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x08play_arc\x18\x04 \x01(\x0b\x32\x1e.bilibili.playershared.PlayArc\x12\x39\n\rqn_trial_info\x18\x05 \x01(\x0b\x32\".bilibili.playershared.QnTrialInfo\x12+\n\x05\x65vent\x18\x06 \x01(\x0b\x32\x1c.bilibili.playershared.Eventb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.pgc.gateway.player.v3.playurl_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLAYVIEWREQ_EXTRACONTENTENTRY._options = None
  _PLAYVIEWREQ_EXTRACONTENTENTRY._serialized_options = b'8\001'
  _PLAYVIEWREQ._serialized_start=150
  _PLAYVIEWREQ._serialized_end=407
  _PLAYVIEWREQ_EXTRACONTENTENTRY._serialized_start=356
  _PLAYVIEWREQ_EXTRACONTENTENTRY._serialized_end=407
  _PLAYVIEWREPLY._serialized_start=410
  _PLAYVIEWREPLY._serialized_end=730
# @@protoc_insertion_point(module_scope)



from ..utils import post

BASE_URL = "https://passport.bilibili.com/x/passport-tv-login/"


async def get_qrcode_login_info(**kwargs):
    """获取二维码登录信息"""
    url = f"{BASE_URL}qrcode/auth_code"
    return await post(url, reqtype="app", **kwargs)


async def get_qrcode_login_result(auth_code: str, **kwargs):
    """获取二维码登录结果"""
    url = f"{BASE_URL}qrcode/poll"
    params = {"auth_code": auth_code}
    return await post(url, params=params, reqtype="app", **kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/community/service/dm/v1/dm.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/community/service/dm/v1/dm.proto\x12 bilibili.community.service.dm.v1\"d\n\x06\x41vatar\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x41\n\x0b\x61vatar_type\x18\x03 \x01(\x0e\x32,.bilibili.community.service.dm.v1.AvatarType\"#\n\x06\x42ubble\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\xc6\x01\n\x08\x42ubbleV2\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x41\n\x0b\x62ubble_type\x18\x03 \x01(\x0e\x32,.bilibili.community.service.dm.v1.BubbleType\x12\x15\n\rexposure_once\x18\x04 \x01(\x08\x12\x45\n\rexposure_type\x18\x05 \x01(\x0e\x32..bilibili.community.service.dm.v1.ExposureType\"&\n\x06\x42utton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x05\"X\n\x0e\x42uzzwordConfig\x12\x46\n\x08keywords\x18\x01 \x03(\x0b\x32\x34.bilibili.community.service.dm.v1.BuzzwordShowConfig\"x\n\x12\x42uzzwordShowConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\x05\x12\n\n\x02id\x18\x04 \x01(\x03\x12\x13\n\x0b\x62uzzword_id\x18\x05 \x01(\x03\x12\x13\n\x0bschema_type\x18\x06 \x01(\x05\"{\n\x08\x43heckBox\x12\x0c\n\x04text\x18\x01 \x01(\t\x12<\n\x04type\x18\x02 \x01(\x0e\x32..bilibili.community.service.dm.v1.CheckboxType\x12\x15\n\rdefault_value\x18\x03 \x01(\x08\x12\x0c\n\x04show\x18\x04 \x01(\x08\"?\n\nCheckBoxV2\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x15\n\rdefault_value\x18\x03 \x01(\x08\"\x82\x02\n\x0b\x43lickButton\x12\x15\n\rportrait_text\x18\x01 \x03(\t\x12\x16\n\x0elandscape_text\x18\x02 \x03(\t\x12\x1b\n\x13portrait_text_focus\x18\x03 \x03(\t\x12\x1c\n\x14landscape_text_focus\x18\x04 \x03(\t\x12\x41\n\x0brender_type\x18\x05 \x01(\x0e\x32,.bilibili.community.service.dm.v1.RenderType\x12\x0c\n\x04show\x18\x06 \x01(\x08\x12\x38\n\x06\x62ubble\x18\x07 \x01(\x0b\x32(.bilibili.community.service.dm.v1.Bubble\"\xd5\x01\n\rClickButtonV2\x12\x15\n\rportrait_text\x18\x01 \x03(\t\x12\x16\n\x0elandscape_text\x18\x02 \x03(\t\x12\x1b\n\x13portrait_text_focus\x18\x03 \x03(\t\x12\x1c\n\x14landscape_text_focus\x18\x04 \x03(\t\x12\x13\n\x0brender_type\x18\x05 \x01(\x05\x12\x17\n\x0ftext_input_post\x18\x06 \x01(\x08\x12\x15\n\rexposure_once\x18\x07 \x01(\x08\x12\x15\n\rexposure_type\x18\x08 \x01(\x05\"\xa1\x01\n\tCommandDm\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12\x10\n\x08progress\x18\x06 \x01(\x05\x12\r\n\x05\x63time\x18\x07 \x01(\t\x12\r\n\x05mtime\x18\x08 \x01(\t\x12\r\n\x05\x65xtra\x18\t \x01(\t\x12\r\n\x05idStr\x18\n \x01(\t\"P\n\rDanmakuAIFlag\x12?\n\x08\x64m_flags\x18\x01 \x03(\x0b\x32-.bilibili.community.service.dm.v1.DanmakuFlag\"\xe9\x01\n\x0b\x44\x61nmakuElem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08progress\x18\x02 \x01(\x05\x12\x0c\n\x04mode\x18\x03 \x01(\x05\x12\x10\n\x08\x66ontsize\x18\x04 \x01(\x05\x12\r\n\x05\x63olor\x18\x05 \x01(\r\x12\x0f\n\x07midHash\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\r\n\x05\x63time\x18\x08 \x01(\x03\x12\x0e\n\x06weight\x18\t \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\n \x01(\t\x12\x0c\n\x04pool\x18\x0b \x01(\x05\x12\r\n\x05idStr\x18\x0c \x01(\t\x12\x0c\n\x04\x61ttr\x18\r \x01(\x05\x12\x11\n\tanimation\x18\x16 \x01(\t\")\n\x0b\x44\x61nmakuFlag\x12\x0c\n\x04\x64mid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66lag\x18\x02 \x01(\r\"K\n\x11\x44\x61nmakuFlagConfig\x12\x10\n\x08rec_flag\x18\x01 \x01(\x05\x12\x10\n\x08rec_text\x18\x02 \x01(\t\x12\x12\n\nrec_switch\x18\x03 \x01(\x05\"\xe4\x06\n\x18\x44\x61nmuDefaultPlayerConfig\x12)\n!player_danmaku_use_default_config\x18\x01 \x01(\x08\x12,\n$player_danmaku_ai_recommended_switch\x18\x04 \x01(\x08\x12+\n#player_danmaku_ai_recommended_level\x18\x05 \x01(\x05\x12\x1f\n\x17player_danmaku_blocktop\x18\x06 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockscroll\x18\x07 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockbottom\x18\x08 \x01(\x08\x12$\n\x1cplayer_danmaku_blockcolorful\x18\t \x01(\x08\x12\"\n\x1aplayer_danmaku_blockrepeat\x18\n \x01(\x08\x12#\n\x1bplayer_danmaku_blockspecial\x18\x0b \x01(\x08\x12\x1e\n\x16player_danmaku_opacity\x18\x0c \x01(\x02\x12$\n\x1cplayer_danmaku_scalingfactor\x18\r \x01(\x02\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\x12\x1c\n\x14player_danmaku_speed\x18\x0f \x01(\x05\x12$\n\x1cinline_player_danmaku_switch\x18\x10 \x01(\x08\x12)\n!player_danmaku_senior_mode_switch\x18\x11 \x01(\x05\x12.\n&player_danmaku_ai_recommended_level_v2\x18\x12 \x01(\x05\x12\x98\x01\n*player_danmaku_ai_recommended_level_v2_map\x18\x13 \x03(\x0b\x32\x64.bilibili.community.service.dm.v1.DanmuDefaultPlayerConfig.PlayerDanmakuAiRecommendedLevelV2MapEntry\x1aK\n)PlayerDanmakuAiRecommendedLevelV2MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\x8f\x08\n\x11\x44\x61nmuPlayerConfig\x12\x1d\n\x15player_danmaku_switch\x18\x01 \x01(\x08\x12\"\n\x1aplayer_danmaku_switch_save\x18\x02 \x01(\x08\x12)\n!player_danmaku_use_default_config\x18\x03 \x01(\x08\x12,\n$player_danmaku_ai_recommended_switch\x18\x04 \x01(\x08\x12+\n#player_danmaku_ai_recommended_level\x18\x05 \x01(\x05\x12\x1f\n\x17player_danmaku_blocktop\x18\x06 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockscroll\x18\x07 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockbottom\x18\x08 \x01(\x08\x12$\n\x1cplayer_danmaku_blockcolorful\x18\t \x01(\x08\x12\"\n\x1aplayer_danmaku_blockrepeat\x18\n \x01(\x08\x12#\n\x1bplayer_danmaku_blockspecial\x18\x0b \x01(\x08\x12\x1e\n\x16player_danmaku_opacity\x18\x0c \x01(\x02\x12$\n\x1cplayer_danmaku_scalingfactor\x18\r \x01(\x02\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\x12\x1c\n\x14player_danmaku_speed\x18\x0f \x01(\x05\x12&\n\x1eplayer_danmaku_enableblocklist\x18\x10 \x01(\x08\x12$\n\x1cinline_player_danmaku_switch\x18\x11 \x01(\x08\x12$\n\x1cinline_player_danmaku_config\x18\x12 \x01(\x05\x12&\n\x1eplayer_danmaku_ios_switch_save\x18\x13 \x01(\x05\x12)\n!player_danmaku_senior_mode_switch\x18\x14 \x01(\x05\x12.\n&player_danmaku_ai_recommended_level_v2\x18\x15 \x01(\x05\x12\x91\x01\n*player_danmaku_ai_recommended_level_v2_map\x18\x16 \x03(\x0b\x32].bilibili.community.service.dm.v1.DanmuPlayerConfig.PlayerDanmakuAiRecommendedLevelV2MapEntry\x1aK\n)PlayerDanmakuAiRecommendedLevelV2MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"0\n\x16\x44\x61nmuPlayerConfigPanel\x12\x16\n\x0eselection_text\x18\x01 \x01(\t\"K\n\x18\x44\x61nmuPlayerDynamicConfig\x12\x10\n\x08progress\x18\x01 \x01(\x05\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\"\x90\x03\n\x15\x44\x61nmuPlayerViewConfig\x12\x61\n\x1d\x64\x61nmuku_default_player_config\x18\x01 \x01(\x0b\x32:.bilibili.community.service.dm.v1.DanmuDefaultPlayerConfig\x12R\n\x15\x64\x61nmuku_player_config\x18\x02 \x01(\x0b\x32\x33.bilibili.community.service.dm.v1.DanmuPlayerConfig\x12\x61\n\x1d\x64\x61nmuku_player_dynamic_config\x18\x03 \x03(\x0b\x32:.bilibili.community.service.dm.v1.DanmuPlayerDynamicConfig\x12]\n\x1b\x64\x61nmuku_player_config_panel\x18\x04 \x01(\x0b\x32\x38.bilibili.community.service.dm.v1.DanmuPlayerConfigPanel\"\xd8\x04\n\x14\x44\x61nmuWebPlayerConfig\x12\x11\n\tdm_switch\x18\x01 \x01(\x08\x12\x11\n\tai_switch\x18\x02 \x01(\x08\x12\x10\n\x08\x61i_level\x18\x03 \x01(\x05\x12\x10\n\x08\x62locktop\x18\x04 \x01(\x08\x12\x13\n\x0b\x62lockscroll\x18\x05 \x01(\x08\x12\x13\n\x0b\x62lockbottom\x18\x06 \x01(\x08\x12\x12\n\nblockcolor\x18\x07 \x01(\x08\x12\x14\n\x0c\x62lockspecial\x18\x08 \x01(\x08\x12\x14\n\x0cpreventshade\x18\t \x01(\x08\x12\r\n\x05\x64mask\x18\n \x01(\x08\x12\x0f\n\x07opacity\x18\x0b \x01(\x02\x12\x0e\n\x06\x64marea\x18\x0c \x01(\x05\x12\x11\n\tspeedplus\x18\r \x01(\x02\x12\x10\n\x08\x66ontsize\x18\x0e \x01(\x02\x12\x12\n\nscreensync\x18\x0f \x01(\x08\x12\x11\n\tspeedsync\x18\x10 \x01(\x08\x12\x12\n\nfontfamily\x18\x11 \x01(\t\x12\x0c\n\x04\x62old\x18\x12 \x01(\x08\x12\x12\n\nfontborder\x18\x13 \x01(\x05\x12\x11\n\tdraw_type\x18\x14 \x01(\t\x12\x1a\n\x12senior_mode_switch\x18\x15 \x01(\x05\x12\x13\n\x0b\x61i_level_v2\x18\x16 \x01(\x05\x12\x61\n\x0f\x61i_level_v2_map\x18\x17 \x03(\x0b\x32H.bilibili.community.service.dm.v1.DanmuWebPlayerConfig.AiLevelV2MapEntry\x1a\x33\n\x11\x41iLevelV2MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"A\n\x0f\x44mExpoReportReq\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\r\n\x05spmid\x18\x04 \x01(\t\"\x11\n\x0f\x44mExpoReportRes\"\xe3\x0c\n\x11\x44mPlayerConfigReq\x12\n\n\x02ts\x18\x01 \x01(\x03\x12\x45\n\x06switch\x18\x02 \x01(\x0b\x32\x35.bilibili.community.service.dm.v1.PlayerDanmakuSwitch\x12N\n\x0bswitch_save\x18\x03 \x01(\x0b\x32\x39.bilibili.community.service.dm.v1.PlayerDanmakuSwitchSave\x12[\n\x12use_default_config\x18\x04 \x01(\x0b\x32?.bilibili.community.service.dm.v1.PlayerDanmakuUseDefaultConfig\x12\x61\n\x15\x61i_recommended_switch\x18\x05 \x01(\x0b\x32\x42.bilibili.community.service.dm.v1.PlayerDanmakuAiRecommendedSwitch\x12_\n\x14\x61i_recommended_level\x18\x06 \x01(\x0b\x32\x41.bilibili.community.service.dm.v1.PlayerDanmakuAiRecommendedLevel\x12I\n\x08\x62locktop\x18\x07 \x01(\x0b\x32\x37.bilibili.community.service.dm.v1.PlayerDanmakuBlocktop\x12O\n\x0b\x62lockscroll\x18\x08 \x01(\x0b\x32:.bilibili.community.service.dm.v1.PlayerDanmakuBlockscroll\x12O\n\x0b\x62lockbottom\x18\t \x01(\x0b\x32:.bilibili.community.service.dm.v1.PlayerDanmakuBlockbottom\x12S\n\rblockcolorful\x18\n \x01(\x0b\x32<.bilibili.community.service.dm.v1.PlayerDanmakuBlockcolorful\x12O\n\x0b\x62lockrepeat\x18\x0b \x01(\x0b\x32:.bilibili.community.service.dm.v1.PlayerDanmakuBlockrepeat\x12Q\n\x0c\x62lockspecial\x18\x0c \x01(\x0b\x32;.bilibili.community.service.dm.v1.PlayerDanmakuBlockspecial\x12G\n\x07opacity\x18\r \x01(\x0b\x32\x36.bilibili.community.service.dm.v1.PlayerDanmakuOpacity\x12S\n\rscalingfactor\x18\x0e \x01(\x0b\x32<.bilibili.community.service.dm.v1.PlayerDanmakuScalingfactor\x12\x45\n\x06\x64omain\x18\x0f \x01(\x0b\x32\x35.bilibili.community.service.dm.v1.PlayerDanmakuDomain\x12\x43\n\x05speed\x18\x10 \x01(\x0b\x32\x34.bilibili.community.service.dm.v1.PlayerDanmakuSpeed\x12W\n\x0f\x65nableblocklist\x18\x11 \x01(\x0b\x32>.bilibili.community.service.dm.v1.PlayerDanmakuEnableblocklist\x12^\n\x19inlinePlayerDanmakuSwitch\x18\x12 \x01(\x0b\x32;.bilibili.community.service.dm.v1.InlinePlayerDanmakuSwitch\x12[\n\x12senior_mode_switch\x18\x13 \x01(\x0b\x32?.bilibili.community.service.dm.v1.PlayerDanmakuSeniorModeSwitch\x12\x64\n\x17\x61i_recommended_level_v2\x18\x14 \x01(\x0b\x32\x43.bilibili.community.service.dm.v1.PlayerDanmakuAiRecommendedLevelV2\"/\n\x0b\x44mSegConfig\x12\x11\n\tpage_size\x18\x01 \x01(\x03\x12\r\n\x05total\x18\x02 \x01(\x03\"\xa1\x01\n\x10\x44mSegMobileReply\x12<\n\x05\x65lems\x18\x01 \x03(\x0b\x32-.bilibili.community.service.dm.v1.DanmakuElem\x12\r\n\x05state\x18\x02 \x01(\x05\x12@\n\x07\x61i_flag\x18\x03 \x01(\x0b\x32/.bilibili.community.service.dm.v1.DanmakuAIFlag\"\xa6\x01\n\x0e\x44mSegMobileReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x15\n\rsegment_index\x18\x04 \x01(\x03\x12\x16\n\x0eteenagers_mode\x18\x05 \x01(\x05\x12\n\n\x02ps\x18\x06 \x01(\x03\x12\n\n\x02pe\x18\x07 \x01(\x03\x12\x11\n\tpull_mode\x18\x08 \x01(\x05\x12\x12\n\nfrom_scene\x18\t \x01(\x05\"]\n\rDmSegOttReply\x12\x0e\n\x06\x63losed\x18\x01 \x01(\x08\x12<\n\x05\x65lems\x18\x02 \x03(\x0b\x32-.bilibili.community.service.dm.v1.DanmakuElem\"L\n\x0b\x44mSegOttReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x15\n\rsegment_index\x18\x04 \x01(\x03\"]\n\rDmSegSDKReply\x12\x0e\n\x06\x63losed\x18\x01 \x01(\x08\x12<\n\x05\x65lems\x18\x02 \x03(\x0b\x32-.bilibili.community.service.dm.v1.DanmakuElem\"L\n\x0b\x44mSegSDKReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x15\n\rsegment_index\x18\x04 \x01(\x03\"\xde\x06\n\x0b\x44mViewReply\x12\x0e\n\x06\x63losed\x18\x01 \x01(\x08\x12\x39\n\x04mask\x18\x02 \x01(\x0b\x32+.bilibili.community.service.dm.v1.VideoMask\x12\x41\n\x08subtitle\x18\x03 \x01(\x0b\x32/.bilibili.community.service.dm.v1.VideoSubtitle\x12\x13\n\x0bspecial_dms\x18\x04 \x03(\t\x12\x44\n\x07\x61i_flag\x18\x05 \x01(\x0b\x32\x33.bilibili.community.service.dm.v1.DanmakuFlagConfig\x12N\n\rplayer_config\x18\x06 \x01(\x0b\x32\x37.bilibili.community.service.dm.v1.DanmuPlayerViewConfig\x12\x16\n\x0esend_box_style\x18\x07 \x01(\x05\x12\r\n\x05\x61llow\x18\x08 \x01(\x08\x12\x11\n\tcheck_box\x18\t \x01(\t\x12\x1a\n\x12\x63heck_box_show_msg\x18\n \x01(\t\x12\x18\n\x10text_placeholder\x18\x0b \x01(\t\x12\x19\n\x11input_placeholder\x18\x0c \x01(\t\x12\x1d\n\x15report_filter_content\x18\r \x03(\t\x12\x41\n\x0b\x65xpo_report\x18\x0e \x01(\x0b\x32,.bilibili.community.service.dm.v1.ExpoReport\x12I\n\x0f\x62uzzword_config\x18\x0f \x01(\x0b\x32\x30.bilibili.community.service.dm.v1.BuzzwordConfig\x12\x42\n\x0b\x65xpressions\x18\x10 \x03(\x0b\x32-.bilibili.community.service.dm.v1.Expressions\x12?\n\npost_panel\x18\x11 \x03(\x0b\x32+.bilibili.community.service.dm.v1.PostPanel\x12\x15\n\ractivity_meta\x18\x12 \x03(\t\x12\x42\n\x0bpost_panel2\x18\x13 \x03(\x0b\x32-.bilibili.community.service.dm.v1.PostPanelV2\"X\n\tDmViewReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\r\n\x05spmid\x18\x04 \x01(\t\x12\x14\n\x0cis_hard_boot\x18\x05 \x01(\x05\"\xc4\x04\n\x0e\x44mWebViewReply\x12\r\n\x05state\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x11\n\ttext_side\x18\x03 \x01(\t\x12=\n\x06\x64m_sge\x18\x04 \x01(\x0b\x32-.bilibili.community.service.dm.v1.DmSegConfig\x12\x41\n\x04\x66lag\x18\x05 \x01(\x0b\x32\x33.bilibili.community.service.dm.v1.DanmakuFlagConfig\x12\x13\n\x0bspecial_dms\x18\x06 \x03(\t\x12\x11\n\tcheck_box\x18\x07 \x01(\x08\x12\r\n\x05\x63ount\x18\x08 \x01(\x03\x12?\n\ncommandDms\x18\t \x03(\x0b\x32+.bilibili.community.service.dm.v1.CommandDm\x12M\n\rplayer_config\x18\n \x01(\x0b\x32\x36.bilibili.community.service.dm.v1.DanmuWebPlayerConfig\x12\x1d\n\x15report_filter_content\x18\x0b \x03(\t\x12\x42\n\x0b\x65xpressions\x18\x0c \x03(\x0b\x32-.bilibili.community.service.dm.v1.Expressions\x12?\n\npost_panel\x18\r \x03(\x0b\x32+.bilibili.community.service.dm.v1.PostPanel\x12\x15\n\ractivity_meta\x18\x0e \x03(\t\"*\n\nExpoReport\x12\x1c\n\x14should_report_at_end\x18\x01 \x01(\x08\"d\n\nExpression\x12\x0f\n\x07keyword\x18\x01 \x03(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x38\n\x06period\x18\x03 \x03(\x0b\x32(.bilibili.community.service.dm.v1.Period\"I\n\x0b\x45xpressions\x12:\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32,.bilibili.community.service.dm.v1.Expression\"*\n\x19InlinePlayerDanmakuSwitch\x12\r\n\x05value\x18\x01 \x01(\x08\"\'\n\x05Label\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x03(\t\"W\n\x07LabelV2\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x03(\t\x12\x15\n\rexposure_once\x18\x03 \x01(\x08\x12\x15\n\rexposure_type\x18\x04 \x01(\x05\"$\n\x06Period\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x03\"0\n\x1fPlayerDanmakuAiRecommendedLevel\x12\r\n\x05value\x18\x01 \x01(\x08\"2\n!PlayerDanmakuAiRecommendedLevelV2\x12\r\n\x05value\x18\x01 \x01(\x05\"1\n PlayerDanmakuAiRecommendedSwitch\x12\r\n\x05value\x18\x01 \x01(\x08\")\n\x18PlayerDanmakuBlockbottom\x12\r\n\x05value\x18\x01 \x01(\x08\"+\n\x1aPlayerDanmakuBlockcolorful\x12\r\n\x05value\x18\x01 \x01(\x08\")\n\x18PlayerDanmakuBlockrepeat\x12\r\n\x05value\x18\x01 \x01(\x08\")\n\x18PlayerDanmakuBlockscroll\x12\r\n\x05value\x18\x01 \x01(\x08\"*\n\x19PlayerDanmakuBlockspecial\x12\r\n\x05value\x18\x01 \x01(\x08\"&\n\x15PlayerDanmakuBlocktop\x12\r\n\x05value\x18\x01 \x01(\x08\"$\n\x13PlayerDanmakuDomain\x12\r\n\x05value\x18\x01 \x01(\x02\"-\n\x1cPlayerDanmakuEnableblocklist\x12\r\n\x05value\x18\x01 \x01(\x08\"%\n\x14PlayerDanmakuOpacity\x12\r\n\x05value\x18\x01 \x01(\x02\"+\n\x1aPlayerDanmakuScalingfactor\x12\r\n\x05value\x18\x01 \x01(\x02\".\n\x1dPlayerDanmakuSeniorModeSwitch\x12\r\n\x05value\x18\x01 \x01(\x05\"#\n\x12PlayerDanmakuSpeed\x12\r\n\x05value\x18\x01 \x01(\x05\"8\n\x13PlayerDanmakuSwitch\x12\r\n\x05value\x18\x01 \x01(\x08\x12\x12\n\ncan_ignore\x18\x02 \x01(\x08\"(\n\x17PlayerDanmakuSwitchSave\x12\r\n\x05value\x18\x01 \x01(\x08\".\n\x1dPlayerDanmakuUseDefaultConfig\x12\r\n\x05value\x18\x01 \x01(\x08\"\x8c\x03\n\tPostPanel\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x03\x12\x10\n\x08priority\x18\x03 \x01(\x03\x12\x0e\n\x06\x62iz_id\x18\x04 \x01(\x03\x12\x44\n\x08\x62iz_type\x18\x05 \x01(\x0e\x32\x32.bilibili.community.service.dm.v1.PostPanelBizType\x12\x43\n\x0c\x63lick_button\x18\x06 \x01(\x0b\x32-.bilibili.community.service.dm.v1.ClickButton\x12?\n\ntext_input\x18\x07 \x01(\x0b\x32+.bilibili.community.service.dm.v1.TextInput\x12=\n\tcheck_box\x18\x08 \x01(\x0b\x32*.bilibili.community.service.dm.v1.CheckBox\x12\x36\n\x05toast\x18\t \x01(\x0b\x32\'.bilibili.community.service.dm.v1.Toast\"\xcb\x03\n\x0bPostPanelV2\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x03\x12\x10\n\x08\x62iz_type\x18\x03 \x01(\x05\x12\x45\n\x0c\x63lick_button\x18\x04 \x01(\x0b\x32/.bilibili.community.service.dm.v1.ClickButtonV2\x12\x41\n\ntext_input\x18\x05 \x01(\x0b\x32-.bilibili.community.service.dm.v1.TextInputV2\x12?\n\tcheck_box\x18\x06 \x01(\x0b\x32,.bilibili.community.service.dm.v1.CheckBoxV2\x12\x38\n\x05toast\x18\x07 \x01(\x0b\x32).bilibili.community.service.dm.v1.ToastV2\x12:\n\x06\x62ubble\x18\x08 \x01(\x0b\x32*.bilibili.community.service.dm.v1.BubbleV2\x12\x38\n\x05label\x18\t \x01(\x0b\x32).bilibili.community.service.dm.v1.LabelV2\x12\x13\n\x0bpost_status\x18\n \x01(\x05\")\n\x08Response\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xf9\x02\n\x0cSubtitleItem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0e\n\x06id_str\x18\x02 \x01(\t\x12\x0b\n\x03lan\x18\x03 \x01(\t\x12\x0f\n\x07lan_doc\x18\x04 \x01(\t\x12\x14\n\x0csubtitle_url\x18\x05 \x01(\t\x12:\n\x06\x61uthor\x18\x06 \x01(\x0b\x32*.bilibili.community.service.dm.v1.UserInfo\x12<\n\x04type\x18\x07 \x01(\x0e\x32..bilibili.community.service.dm.v1.SubtitleType\x12\x15\n\rlan_doc_brief\x18\x08 \x01(\t\x12\x41\n\x07\x61i_type\x18\t \x01(\x0e\x32\x30.bilibili.community.service.dm.v1.SubtitleAiType\x12\x45\n\tai_status\x18\n \x01(\x0e\x32\x32.bilibili.community.service.dm.v1.SubtitleAiStatus\"\xe8\x02\n\tTextInput\x12\x1c\n\x14portrait_placeholder\x18\x01 \x03(\t\x12\x1d\n\x15landscape_placeholder\x18\x02 \x03(\t\x12\x41\n\x0brender_type\x18\x03 \x01(\x0e\x32,.bilibili.community.service.dm.v1.RenderType\x12\x18\n\x10placeholder_post\x18\x04 \x01(\x08\x12\x0c\n\x04show\x18\x05 \x01(\x08\x12\x38\n\x06\x61vatar\x18\x06 \x03(\x0b\x32(.bilibili.community.service.dm.v1.Avatar\x12\x41\n\x0bpost_status\x18\x07 \x01(\x0e\x32,.bilibili.community.service.dm.v1.PostStatus\x12\x36\n\x05label\x18\x08 \x01(\x0b\x32\'.bilibili.community.service.dm.v1.Label\"\xfb\x01\n\x0bTextInputV2\x12\x1c\n\x14portrait_placeholder\x18\x01 \x03(\t\x12\x1d\n\x15landscape_placeholder\x18\x02 \x03(\t\x12\x41\n\x0brender_type\x18\x03 \x01(\x0e\x32,.bilibili.community.service.dm.v1.RenderType\x12\x18\n\x10placeholder_post\x18\x04 \x01(\x08\x12\x38\n\x06\x61vatar\x18\x05 \x03(\x0b\x32(.bilibili.community.service.dm.v1.Avatar\x12\x18\n\x10text_input_limit\x18\x06 \x01(\x05\"o\n\x05Toast\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\x05\x12\x0c\n\x04show\x18\x03 \x01(\x08\x12\x38\n\x06\x62utton\x18\x04 \x01(\x0b\x32(.bilibili.community.service.dm.v1.Button\"-\n\rToastButtonV2\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x05\"s\n\x07ToastV2\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\x05\x12H\n\x0ftoast_button_v2\x18\x03 \x01(\x0b\x32/.bilibili.community.service.dm.v1.ToastButtonV2\"\\\n\x08UserInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sex\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\x0c\n\x04sign\x18\x05 \x01(\t\x12\x0c\n\x04rank\x18\x06 \x01(\x05\"S\n\tVideoMask\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x0c\n\x04plat\x18\x02 \x01(\x05\x12\x0b\n\x03\x66ps\x18\x03 \x01(\x05\x12\x0c\n\x04time\x18\x04 \x01(\x03\x12\x10\n\x08mask_url\x18\x05 \x01(\t\"o\n\rVideoSubtitle\x12\x0b\n\x03lan\x18\x01 \x01(\t\x12\x0e\n\x06lanDoc\x18\x02 \x01(\t\x12\x41\n\tsubtitles\x18\x03 \x03(\x0b\x32..bilibili.community.service.dm.v1.SubtitleItem*3\n\nAvatarType\x12\x12\n\x0e\x41vatarTypeNone\x10\x00\x12\x11\n\rAvatarTypeNFT\x10\x01*Y\n\nBubbleType\x12\x12\n\x0e\x42ubbleTypeNone\x10\x00\x12\x19\n\x15\x42ubbleTypeClickButton\x10\x01\x12\x1c\n\x18\x42ubbleTypeDmSettingPanel\x10\x02*X\n\x0c\x43heckboxType\x12\x14\n\x10\x43heckboxTypeNone\x10\x00\x12\x19\n\x15\x43heckboxTypeEncourage\x10\x01\x12\x17\n\x13\x43heckboxTypeColorDM\x10\x02*L\n\tDMAttrBit\x12\x14\n\x10\x44MAttrBitProtect\x10\x00\x12\x15\n\x11\x44MAttrBitFromLive\x10\x01\x12\x12\n\x0e\x44MAttrHighLike\x10\x02*<\n\x0c\x45xposureType\x12\x14\n\x10\x45xposureTypeNone\x10\x00\x12\x16\n\x12\x45xposureTypeDMSend\x10\x01*\xc1\x01\n\x10PostPanelBizType\x12\x18\n\x14PostPanelBizTypeNone\x10\x00\x12\x1d\n\x19PostPanelBizTypeEncourage\x10\x01\x12\x1b\n\x17PostPanelBizTypeColorDM\x10\x02\x12\x19\n\x15PostPanelBizTypeNFTDM\x10\x03\x12\x1d\n\x19PostPanelBizTypeFragClose\x10\x04\x12\x1d\n\x19PostPanelBizTypeRecommend\x10\x05*8\n\nPostStatus\x12\x14\n\x10PostStatusNormal\x10\x00\x12\x14\n\x10PostStatusClosed\x10\x01*N\n\nRenderType\x12\x12\n\x0eRenderTypeNone\x10\x00\x12\x14\n\x10RenderTypeSingle\x10\x01\x12\x16\n\x12RenderTypeRotation\x10\x02*6\n\x10SubtitleAiStatus\x12\x08\n\x04None\x10\x00\x12\x0c\n\x08\x45xposure\x10\x01\x12\n\n\x06\x41ssist\x10\x02*+\n\x0eSubtitleAiType\x12\n\n\x06Normal\x10\x00\x12\r\n\tTranslate\x10\x01*\x1e\n\x0cSubtitleType\x12\x06\n\x02\x43\x43\x10\x00\x12\x06\n\x02\x41I\x10\x01*N\n\x11ToastFunctionType\x12\x19\n\x15ToastFunctionTypeNone\x10\x00\x12\x1e\n\x1aToastFunctionTypePostPanel\x10\x01\x32\xa0\x05\n\x02\x44M\x12s\n\x0b\x44mSegMobile\x12\x30.bilibili.community.service.dm.v1.DmSegMobileReq\x1a\x32.bilibili.community.service.dm.v1.DmSegMobileReply\x12\x64\n\x06\x44mView\x12+.bilibili.community.service.dm.v1.DmViewReq\x1a-.bilibili.community.service.dm.v1.DmViewReply\x12q\n\x0e\x44mPlayerConfig\x12\x33.bilibili.community.service.dm.v1.DmPlayerConfigReq\x1a*.bilibili.community.service.dm.v1.Response\x12j\n\x08\x44mSegOtt\x12-.bilibili.community.service.dm.v1.DmSegOttReq\x1a/.bilibili.community.service.dm.v1.DmSegOttReply\x12j\n\x08\x44mSegSDK\x12-.bilibili.community.service.dm.v1.DmSegSDKReq\x1a/.bilibili.community.service.dm.v1.DmSegSDKReply\x12t\n\x0c\x44mExpoReport\x12\x31.bilibili.community.service.dm.v1.DmExpoReportReq\x1a\x31.bilibili.community.service.dm.v1.DmExpoReportResb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.community.service.dm.v1.dm_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DANMUDEFAULTPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY._options = None
  _DANMUDEFAULTPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY._serialized_options = b'8\001'
  _DANMUPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY._options = None
  _DANMUPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY._serialized_options = b'8\001'
  _DANMUWEBPLAYERCONFIG_AILEVELV2MAPENTRY._options = None
  _DANMUWEBPLAYERCONFIG_AILEVELV2MAPENTRY._serialized_options = b'8\001'
  _AVATARTYPE._serialized_start=12692
  _AVATARTYPE._serialized_end=12743
  _BUBBLETYPE._serialized_start=12745
  _BUBBLETYPE._serialized_end=12834
  _CHECKBOXTYPE._serialized_start=12836
  _CHECKBOXTYPE._serialized_end=12924
  _DMATTRBIT._serialized_start=12926
  _DMATTRBIT._serialized_end=13002
  _EXPOSURETYPE._serialized_start=13004
  _EXPOSURETYPE._serialized_end=13064
  _POSTPANELBIZTYPE._serialized_start=13067
  _POSTPANELBIZTYPE._serialized_end=13260
  _POSTSTATUS._serialized_start=13262
  _POSTSTATUS._serialized_end=13318
  _RENDERTYPE._serialized_start=13320
  _RENDERTYPE._serialized_end=13398
  _SUBTITLEAISTATUS._serialized_start=13400
  _SUBTITLEAISTATUS._serialized_end=13454
  _SUBTITLEAITYPE._serialized_start=13456
  _SUBTITLEAITYPE._serialized_end=13499
  _SUBTITLETYPE._serialized_start=13501
  _SUBTITLETYPE._serialized_end=13531
  _TOASTFUNCTIONTYPE._serialized_start=13533
  _TOASTFUNCTIONTYPE._serialized_end=13611
  _AVATAR._serialized_start=79
  _AVATAR._serialized_end=179
  _BUBBLE._serialized_start=181
  _BUBBLE._serialized_end=216
  _BUBBLEV2._serialized_start=219
  _BUBBLEV2._serialized_end=417
  _BUTTON._serialized_start=419
  _BUTTON._serialized_end=457
  _BUZZWORDCONFIG._serialized_start=459
  _BUZZWORDCONFIG._serialized_end=547
  _BUZZWORDSHOWCONFIG._serialized_start=549
  _BUZZWORDSHOWCONFIG._serialized_end=669
  _CHECKBOX._serialized_start=671
  _CHECKBOX._serialized_end=794
  _CHECKBOXV2._serialized_start=796
  _CHECKBOXV2._serialized_end=859
  _CLICKBUTTON._serialized_start=862
  _CLICKBUTTON._serialized_end=1120
  _CLICKBUTTONV2._serialized_start=1123
  _CLICKBUTTONV2._serialized_end=1336
  _COMMANDDM._serialized_start=1339
  _COMMANDDM._serialized_end=1500
  _DANMAKUAIFLAG._serialized_start=1502
  _DANMAKUAIFLAG._serialized_end=1582
  _DANMAKUELEM._serialized_start=1585
  _DANMAKUELEM._serialized_end=1818
  _DANMAKUFLAG._serialized_start=1820
  _DANMAKUFLAG._serialized_end=1861
  _DANMAKUFLAGCONFIG._serialized_start=1863
  _DANMAKUFLAGCONFIG._serialized_end=1938
  _DANMUDEFAULTPLAYERCONFIG._serialized_start=1941
  _DANMUDEFAULTPLAYERCONFIG._serialized_end=2809
  _DANMUDEFAULTPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY._serialized_start=2734
  _DANMUDEFAULTPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY._serialized_end=2809
  _DANMUPLAYERCONFIG._serialized_start=2812
  _DANMUPLAYERCONFIG._serialized_end=3851
  _DANMUPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY._serialized_start=2734
  _DANMUPLAYERCONFIG_PLAYERDANMAKUAIRECOMMENDEDLEVELV2MAPENTRY._serialized_end=2809
  _DANMUPLAYERCONFIGPANEL._serialized_start=3853
  _DANMUPLAYERCONFIGPANEL._serialized_end=3901
  _DANMUPLAYERDYNAMICCONFIG._serialized_start=3903
  _DANMUPLAYERDYNAMICCONFIG._serialized_end=3978
  _DANMUPLAYERVIEWCONFIG._serialized_start=3981
  _DANMUPLAYERVIEWCONFIG._serialized_end=4381
  _DANMUWEBPLAYERCONFIG._serialized_start=4384
  _DANMUWEBPLAYERCONFIG._serialized_end=4984
  _DANMUWEBPLAYERCONFIG_AILEVELV2MAPENTRY._serialized_start=4933
  _DANMUWEBPLAYERCONFIG_AILEVELV2MAPENTRY._serialized_end=4984
  _DMEXPOREPORTREQ._serialized_start=4986
  _DMEXPOREPORTREQ._serialized_end=5051
  _DMEXPOREPORTRES._serialized_start=5053
  _DMEXPOREPORTRES._serialized_end=5070
  _DMPLAYERCONFIGREQ._serialized_start=5073
  _DMPLAYERCONFIGREQ._serialized_end=6708
  _DMSEGCONFIG._serialized_start=6710
  _DMSEGCONFIG._serialized_end=6757
  _DMSEGMOBILEREPLY._serialized_start=6760
  _DMSEGMOBILEREPLY._serialized_end=6921
  _DMSEGMOBILEREQ._serialized_start=6924
  _DMSEGMOBILEREQ._serialized_end=7090
  _DMSEGOTTREPLY._serialized_start=7092
  _DMSEGOTTREPLY._serialized_end=7185
  _DMSEGOTTREQ._serialized_start=7187
  _DMSEGOTTREQ._serialized_end=7263
  _DMSEGSDKREPLY._serialized_start=7265
  _DMSEGSDKREPLY._serialized_end=7358
  _DMSEGSDKREQ._serialized_start=7360
  _DMSEGSDKREQ._serialized_end=7436
  _DMVIEWREPLY._serialized_start=7439
  _DMVIEWREPLY._serialized_end=8301
  _DMVIEWREQ._serialized_start=8303
  _DMVIEWREQ._serialized_end=8391
  _DMWEBVIEWREPLY._serialized_start=8394
  _DMWEBVIEWREPLY._serialized_end=8974
  _EXPOREPORT._serialized_start=8976
  _EXPOREPORT._serialized_end=9018
  _EXPRESSION._serialized_start=9020
  _EXPRESSION._serialized_end=9120
  _EXPRESSIONS._serialized_start=9122
  _EXPRESSIONS._serialized_end=9195
  _INLINEPLAYERDANMAKUSWITCH._serialized_start=9197
  _INLINEPLAYERDANMAKUSWITCH._serialized_end=9239
  _LABEL._serialized_start=9241
  _LABEL._serialized_end=9280
  _LABELV2._serialized_start=9282
  _LABELV2._serialized_end=9369
  _PERIOD._serialized_start=9371
  _PERIOD._serialized_end=9407
  _PLAYERDANMAKUAIRECOMMENDEDLEVEL._serialized_start=9409
  _PLAYERDANMAKUAIRECOMMENDEDLEVEL._serialized_end=9457
  _PLAYERDANMAKUAIRECOMMENDEDLEVELV2._serialized_start=9459
  _PLAYERDANMAKUAIRECOMMENDEDLEVELV2._serialized_end=9509
  _PLAYERDANMAKUAIRECOMMENDEDSWITCH._serialized_start=9511
  _PLAYERDANMAKUAIRECOMMENDEDSWITCH._serialized_end=9560
  _PLAYERDANMAKUBLOCKBOTTOM._serialized_start=9562
  _PLAYERDANMAKUBLOCKBOTTOM._serialized_end=9603
  _PLAYERDANMAKUBLOCKCOLORFUL._serialized_start=9605
  _PLAYERDANMAKUBLOCKCOLORFUL._serialized_end=9648
  _PLAYERDANMAKUBLOCKREPEAT._serialized_start=9650
  _PLAYERDANMAKUBLOCKREPEAT._serialized_end=9691
  _PLAYERDANMAKUBLOCKSCROLL._serialized_start=9693
  _PLAYERDANMAKUBLOCKSCROLL._serialized_end=9734
  _PLAYERDANMAKUBLOCKSPECIAL._serialized_start=9736
  _PLAYERDANMAKUBLOCKSPECIAL._serialized_end=9778
  _PLAYERDANMAKUBLOCKTOP._serialized_start=9780
  _PLAYERDANMAKUBLOCKTOP._serialized_end=9818
  _PLAYERDANMAKUDOMAIN._serialized_start=9820
  _PLAYERDANMAKUDOMAIN._serialized_end=9856
  _PLAYERDANMAKUENABLEBLOCKLIST._serialized_start=9858
  _PLAYERDANMAKUENABLEBLOCKLIST._serialized_end=9903
  _PLAYERDANMAKUOPACITY._serialized_start=9905
  _PLAYERDANMAKUOPACITY._serialized_end=9942
  _PLAYERDANMAKUSCALINGFACTOR._serialized_start=9944
  _PLAYERDANMAKUSCALINGFACTOR._serialized_end=9987
  _PLAYERDANMAKUSENIORMODESWITCH._serialized_start=9989
  _PLAYERDANMAKUSENIORMODESWITCH._serialized_end=10035
  _PLAYERDANMAKUSPEED._serialized_start=10037
  _PLAYERDANMAKUSPEED._serialized_end=10072
  _PLAYERDANMAKUSWITCH._serialized_start=10074
  _PLAYERDANMAKUSWITCH._serialized_end=10130
  _PLAYERDANMAKUSWITCHSAVE._serialized_start=10132
  _PLAYERDANMAKUSWITCHSAVE._serialized_end=10172
  _PLAYERDANMAKUUSEDEFAULTCONFIG._serialized_start=10174
  _PLAYERDANMAKUUSEDEFAULTCONFIG._serialized_end=10220
  _POSTPANEL._serialized_start=10223
  _POSTPANEL._serialized_end=10619
  _POSTPANELV2._serialized_start=10622
  _POSTPANELV2._serialized_end=11081
  _RESPONSE._serialized_start=11083
  _RESPONSE._serialized_end=11124
  _SUBTITLEITEM._serialized_start=11127
  _SUBTITLEITEM._serialized_end=11504
  _TEXTINPUT._serialized_start=11507
  _TEXTINPUT._serialized_end=11867
  _TEXTINPUTV2._serialized_start=11870
  _TEXTINPUTV2._serialized_end=12121
  _TOAST._serialized_start=12123
  _TOAST._serialized_end=12234
  _TOASTBUTTONV2._serialized_start=12236
  _TOASTBUTTONV2._serialized_end=12281
  _TOASTV2._serialized_start=12283
  _TOASTV2._serialized_end=12398
  _USERINFO._serialized_start=12400
  _USERINFO._serialized_end=12492
  _VIDEOMASK._serialized_start=12494
  _VIDEOMASK._serialized_end=12577
  _VIDEOSUBTITLE._serialized_start=12579
  _VIDEOSUBTITLE._serialized_end=12690
  _DM._serialized_start=13614
  _DM._serialized_end=14286
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Exp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    bucket: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        bucket: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "id", b"id"]) -> None: ...

global___Exp = Exp

@typing_extensions.final
class Exps(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPS_FIELD_NUMBER: builtins.int
    @property
    def exps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Exp]:
        """"""
    def __init__(
        self,
        *,
        exps: collections.abc.Iterable[global___Exp] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exps", b"exps"]) -> None: ...

global___Exps = Exps



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ShowStrategy(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    STIME_FIELD_NUMBER: builtins.int
    ETIME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    stime: builtins.int
    """"""
    etime: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        stime: builtins.int = ...,
        etime: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["etime", b"etime", "id", b"id", "stime", b"stime"]) -> None: ...

global___ShowStrategy = ShowStrategy

@typing_extensions.final
class SplashItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    BEGIN_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    THUMB_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    LOGO_URL_FIELD_NUMBER: builtins.int
    LOGO_HASH_FIELD_NUMBER: builtins.int
    VIDEO_URL_FIELD_NUMBER: builtins.int
    VIDEO_HASH_FIELD_NUMBER: builtins.int
    VIDEO_WIDTH_FIELD_NUMBER: builtins.int
    VIDEO_HEIGHT_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SCHEMA_TITLE_FIELD_NUMBER: builtins.int
    SCHEMA_PACKAGE_NAME_FIELD_NUMBER: builtins.int
    SCHEMA_CALLUP_WHITELIST_FIELD_NUMBER: builtins.int
    SKIP_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    URI_TITLE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    CM_MARK_FIELD_NUMBER: builtins.int
    AD_CB_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    CLIENT_IP_FIELD_NUMBER: builtins.int
    IS_AD_FIELD_NUMBER: builtins.int
    IS_AD_LOC_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    CARD_INDEX_FIELD_NUMBER: builtins.int
    SERVER_TYPE_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    CLICK_URL_FIELD_NUMBER: builtins.int
    SHOW_URL_FIELD_NUMBER: builtins.int
    TIME_TARGET_FIELD_NUMBER: builtins.int
    ENCRYPTION_FIELD_NUMBER: builtins.int
    ENABLE_PRE_DOWNLOAD_FIELD_NUMBER: builtins.int
    ENABLE_BACKGROUND_DOWNLOAD_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    type: builtins.int
    """"""
    card_type: builtins.int
    """"""
    duration: builtins.int
    """"""
    begin_time: builtins.int
    """"""
    end_time: builtins.int
    """"""
    thumb: builtins.str
    """"""
    hash: builtins.str
    """"""
    logo_url: builtins.str
    """"""
    logo_hash: builtins.str
    """"""
    video_url: builtins.str
    """"""
    video_hash: builtins.str
    """"""
    video_width: builtins.int
    """"""
    video_height: builtins.int
    """"""
    schema: builtins.str
    """"""
    schema_title: builtins.str
    """"""
    schema_package_name: builtins.str
    """"""
    @property
    def schema_callup_whiteList(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    skip: builtins.int
    """"""
    uri: builtins.str
    """"""
    uri_title: builtins.str
    """"""
    source: builtins.int
    """"""
    cm_mark: builtins.int
    """"""
    ad_cb: builtins.str
    """"""
    resource_id: builtins.int
    """"""
    request_id: builtins.str
    """"""
    client_ip: builtins.str
    """"""
    is_ad: builtins.bool
    """"""
    is_ad_loc: builtins.bool
    """"""
    @property
    def extra(self) -> google.protobuf.any_pb2.Any:
        """"""
    card_index: builtins.int
    """"""
    server_type: builtins.int
    """"""
    index: builtins.int
    """"""
    click_url: builtins.str
    """"""
    show_url: builtins.str
    """"""
    time_target: builtins.int
    """"""
    encryption: builtins.int
    """"""
    enable_pre_download: builtins.bool
    """"""
    enable_background_download: builtins.bool
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        type: builtins.int = ...,
        card_type: builtins.int = ...,
        duration: builtins.int = ...,
        begin_time: builtins.int = ...,
        end_time: builtins.int = ...,
        thumb: builtins.str = ...,
        hash: builtins.str = ...,
        logo_url: builtins.str = ...,
        logo_hash: builtins.str = ...,
        video_url: builtins.str = ...,
        video_hash: builtins.str = ...,
        video_width: builtins.int = ...,
        video_height: builtins.int = ...,
        schema: builtins.str = ...,
        schema_title: builtins.str = ...,
        schema_package_name: builtins.str = ...,
        schema_callup_whiteList: collections.abc.Iterable[builtins.str] | None = ...,
        skip: builtins.int = ...,
        uri: builtins.str = ...,
        uri_title: builtins.str = ...,
        source: builtins.int = ...,
        cm_mark: builtins.int = ...,
        ad_cb: builtins.str = ...,
        resource_id: builtins.int = ...,
        request_id: builtins.str = ...,
        client_ip: builtins.str = ...,
        is_ad: builtins.bool = ...,
        is_ad_loc: builtins.bool = ...,
        extra: google.protobuf.any_pb2.Any | None = ...,
        card_index: builtins.int = ...,
        server_type: builtins.int = ...,
        index: builtins.int = ...,
        click_url: builtins.str = ...,
        show_url: builtins.str = ...,
        time_target: builtins.int = ...,
        encryption: builtins.int = ...,
        enable_pre_download: builtins.bool = ...,
        enable_background_download: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extra", b"extra"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_cb", b"ad_cb", "begin_time", b"begin_time", "card_index", b"card_index", "card_type", b"card_type", "click_url", b"click_url", "client_ip", b"client_ip", "cm_mark", b"cm_mark", "duration", b"duration", "enable_background_download", b"enable_background_download", "enable_pre_download", b"enable_pre_download", "encryption", b"encryption", "end_time", b"end_time", "extra", b"extra", "hash", b"hash", "id", b"id", "index", b"index", "is_ad", b"is_ad", "is_ad_loc", b"is_ad_loc", "logo_hash", b"logo_hash", "logo_url", b"logo_url", "request_id", b"request_id", "resource_id", b"resource_id", "schema", b"schema", "schema_callup_whiteList", b"schema_callup_whiteList", "schema_package_name", b"schema_package_name", "schema_title", b"schema_title", "server_type", b"server_type", "show_url", b"show_url", "skip", b"skip", "source", b"source", "thumb", b"thumb", "time_target", b"time_target", "type", b"type", "uri", b"uri", "uri_title", b"uri_title", "video_hash", b"video_hash", "video_height", b"video_height", "video_url", b"video_url", "video_width", b"video_width"]) -> None: ...

global___SplashItem = SplashItem

@typing_extensions.final
class SplashReply(google.protobuf.message.Message):
    """-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_TIME_FIELD_NUMBER: builtins.int
    MIN_INTERVAL_FIELD_NUMBER: builtins.int
    PULL_INTERVAL_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    SHOW_FIELD_NUMBER: builtins.int
    max_time: builtins.int
    """"""
    min_interval: builtins.int
    """"""
    pull_interval: builtins.int
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SplashItem]:
        """"""
    @property
    def show(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShowStrategy]:
        """"""
    def __init__(
        self,
        *,
        max_time: builtins.int = ...,
        min_interval: builtins.int = ...,
        pull_interval: builtins.int = ...,
        list: collections.abc.Iterable[global___SplashItem] | None = ...,
        show: collections.abc.Iterable[global___ShowStrategy] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list", "max_time", b"max_time", "min_interval", b"min_interval", "pull_interval", b"pull_interval", "show", b"show"]) -> None: ...

global___SplashReply = SplashReply

@typing_extensions.final
class SplashReq(google.protobuf.message.Message):
    """-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    BIRTH_FIELD_NUMBER: builtins.int
    AD_EXTRA_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    width: builtins.int
    """"""
    height: builtins.int
    """"""
    birth: builtins.str
    """"""
    ad_extra: builtins.str
    """"""
    network: builtins.str
    """"""
    def __init__(
        self,
        *,
        width: builtins.int = ...,
        height: builtins.int = ...,
        birth: builtins.str = ...,
        ad_extra: builtins.str = ...,
        network: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_extra", b"ad_extra", "birth", b"birth", "height", b"height", "network", b"network", "width", b"width"]) -> None: ...

global___SplashReq = SplashReq



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PLType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PLTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PLType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EN_PAYLOAD_NORMAL: _PLType.ValueType  # 0
    """"""
    EN_PAYLOAD_BASE64: _PLType.ValueType  # 1
    """"""

class PLType(_PLType, metaclass=_PLTypeEnumTypeWrapper):
    """"""

EN_PAYLOAD_NORMAL: PLType.ValueType  # 0
""""""
EN_PAYLOAD_BASE64: PLType.ValueType  # 1
""""""
global___PLType = PLType

class _CmdId:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CmdIdEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CmdId.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EN_CMD_ID_INVALID: _CmdId.ValueType  # 0
    """非法cmd"""
    EN_CMD_ID_MSG_NOTIFY: _CmdId.ValueType  # 1
    """服务端主动发起"""
    EN_CMD_ID_KICK_OUT: _CmdId.ValueType  # 2
    """"""

class CmdId(_CmdId, metaclass=_CmdIdEnumTypeWrapper):
    """"""

EN_CMD_ID_INVALID: CmdId.ValueType  # 0
"""非法cmd"""
EN_CMD_ID_MSG_NOTIFY: CmdId.ValueType  # 1
"""服务端主动发起"""
EN_CMD_ID_KICK_OUT: CmdId.ValueType  # 2
""""""
global___CmdId = CmdId

@typing_extensions.final
class NotifyRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    CMD_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    PAYLOAD_TYPE_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""
    cmd: builtins.int
    """命令id"""
    payload: builtins.bytes
    """"""
    payload_type: global___PLType.ValueType
    """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        cmd: builtins.int = ...,
        payload: builtins.bytes = ...,
        payload_type: global___PLType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cmd", b"cmd", "payload", b"payload", "payload_type", b"payload_type", "uid", b"uid"]) -> None: ...

global___NotifyRsp = NotifyRsp

@typing_extensions.final
class Msg(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_UID_FIELD_NUMBER: builtins.int
    RECEIVER_TYPE_FIELD_NUMBER: builtins.int
    RECEIVER_ID_FIELD_NUMBER: builtins.int
    CLI_MSG_ID_FIELD_NUMBER: builtins.int
    MSG_TYPE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    MSG_SEQNO_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    AT_UIDS_FIELD_NUMBER: builtins.int
    RECVER_IDS_FIELD_NUMBER: builtins.int
    MSG_KEY_FIELD_NUMBER: builtins.int
    MSG_STATUS_FIELD_NUMBER: builtins.int
    SYS_CANCEL_FIELD_NUMBER: builtins.int
    IS_MULTI_CHAT_FIELD_NUMBER: builtins.int
    WITHDRAW_SEQNO_FIELD_NUMBER: builtins.int
    NOTIFY_CODE_FIELD_NUMBER: builtins.int
    MSG_SOURCE_FIELD_NUMBER: builtins.int
    sender_uid: builtins.int
    """发送方uid"""
    receiver_type: builtins.int
    """接收方类型"""
    receiver_id: builtins.int
    """接收方id"""
    cli_msg_id: builtins.int
    """客户端的序列id 用于服务端去重"""
    msg_type: builtins.int
    """消息类型"""
    content: builtins.str
    """消息内容"""
    msg_seqno: builtins.int
    """服务端的序列号"""
    timestamp: builtins.int
    """消息发送时间（服务端时间）"""
    @property
    def at_uids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """at用户列表"""
    @property
    def recver_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """多人消息"""
    msg_key: builtins.int
    """消息唯一标示"""
    msg_status: builtins.int
    """消息状态"""
    sys_cancel: builtins.bool
    """是否为系统撤销"""
    is_multi_chat: builtins.int
    """是否是多聊消息 目前群通知管理员的部分通知属于该类消息"""
    withdraw_seqno: builtins.int
    """表示撤回的消息的session_seqno 用以后续的比较 实现未读数的正确显示"""
    notify_code: builtins.str
    """通知码"""
    msg_source: builtins.int
    """消息来源"""
    def __init__(
        self,
        *,
        sender_uid: builtins.int = ...,
        receiver_type: builtins.int = ...,
        receiver_id: builtins.int = ...,
        cli_msg_id: builtins.int = ...,
        msg_type: builtins.int = ...,
        content: builtins.str = ...,
        msg_seqno: builtins.int = ...,
        timestamp: builtins.int = ...,
        at_uids: collections.abc.Iterable[builtins.int] | None = ...,
        recver_ids: collections.abc.Iterable[builtins.int] | None = ...,
        msg_key: builtins.int = ...,
        msg_status: builtins.int = ...,
        sys_cancel: builtins.bool = ...,
        is_multi_chat: builtins.int = ...,
        withdraw_seqno: builtins.int = ...,
        notify_code: builtins.str = ...,
        msg_source: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["at_uids", b"at_uids", "cli_msg_id", b"cli_msg_id", "content", b"content", "is_multi_chat", b"is_multi_chat", "msg_key", b"msg_key", "msg_seqno", b"msg_seqno", "msg_source", b"msg_source", "msg_status", b"msg_status", "msg_type", b"msg_type", "notify_code", b"notify_code", "receiver_id", b"receiver_id", "receiver_type", b"receiver_type", "recver_ids", b"recver_ids", "sender_uid", b"sender_uid", "sys_cancel", b"sys_cancel", "timestamp", b"timestamp", "withdraw_seqno", b"withdraw_seqno"]) -> None: ...

global___Msg = Msg

@typing_extensions.final
class NotifyInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_TYPE_FIELD_NUMBER: builtins.int
    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    msg_type: builtins.int
    """"""
    talker_id: builtins.int
    """"""
    session_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        msg_type: builtins.int = ...,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg_type", b"msg_type", "session_type", b"session_type", "talker_id", b"talker_id"]) -> None: ...

global___NotifyInfo = NotifyInfo

@typing_extensions.final
class ReqServerNotify(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LASTEST_SEQNO_FIELD_NUMBER: builtins.int
    INSTANT_MSG_FIELD_NUMBER: builtins.int
    NOTIFY_INFO_FIELD_NUMBER: builtins.int
    lastest_seqno: builtins.int
    """最新序列号"""
    @property
    def instant_msg(self) -> global___Msg:
        """即时消息 该类消息主要用于系统通知 当客户端sync msg时 不会sync到此类消息"""
    @property
    def notify_info(self) -> global___NotifyInfo:
        """"""
    def __init__(
        self,
        *,
        lastest_seqno: builtins.int = ...,
        instant_msg: global___Msg | None = ...,
        notify_info: global___NotifyInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["instant_msg", b"instant_msg", "notify_info", b"notify_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instant_msg", b"instant_msg", "lastest_seqno", b"lastest_seqno", "notify_info", b"notify_info"]) -> None: ...

global___ReqServerNotify = ReqServerNotify
